import { IPoint } from '../model/IPoint';

// odmocnina ze souctu druhych mocnin
Math.hypot = Math.hypot || function () {
    let y = 0;
    let length = arguments.length;

    for (let i = 0; i < length; i++) {
        if (arguments[i] === Infinity || arguments[i] === -Infinity) {
            return Infinity;
        }
        y += arguments[i] * arguments[i];
    }
    return Math.sqrt(y);
};

// lineární interpolace
export function linearInterpolation(a: number, b: number, t: number) {
    return (1 - t) * a + t * b;
}

// výpočet vektoru a normály
export function computeNormal(x1: number, x2: number, y1: number, y2: number)
    : IPoint {
    let v1 = x2 - x1;
    let v2 = -(y2 - y1);
    let u1 = -v2;
    let u2 = v1;

    return { x: u1, y: u2 };
}

// výpočet nového bodu lineární interpolací
export function computeNewPoint(
    normal: IPoint, x1: number,
    y1: number, moved: number): IPoint {
    let lengthOfNormal = Math.hypot(normal.x, normal.y);
    let interpolationParameter = (!!moved && moved) / lengthOfNormal;
    let newX = linearInterpolation(x1, x1 + normal.x, interpolationParameter);
    let newY = linearInterpolation(y1, y1 - normal.y, interpolationParameter);

    return { x: newX, y: newY };
}

// výpočet celé pozice hrany
export function computeMovedPosition(
    x1: number, x2: number,
    y1: number, y2: number, moved: number): IPoint[] {
    let firstNormal = computeNormal(x1, x2, y1, y2);
    let secondNormal = computeNormal(x2, x1, y2, y1);
    let firstPoint = computeNewPoint(firstNormal, x1, y1, moved);
    let secondPoint = computeNewPoint(secondNormal, x2, y2, -moved);

    return [firstPoint, secondPoint];
}