import * as b from 'bobril';
import * as bs from 'bobrilstrap';
import * as colors from '../../common/colors';
import * as constants from '../../common/constants';

const progressBarStyle = b.styleDef({
    backgroundColor: colors.grayLight,
    height: 10
});

const progressWrapStyle = b.styleDef({
    width: '20%',
    height: 40,
    padding: 15,
    backgroundColor: colors.grayLight,
    display: 'inline-block',
    verticalAlign: 'middle',
    border: 'none'
});

export interface IProgressBarData {
    children?: b.IBobrilChildren;
    onePercentValue: number;
    onDone?: () => void;
    onStarted?: () => void;
}

interface IProgressBarCtx extends b.IBobrilCtx {
    data: IProgressBarData;
    progress: number;
    onePercentValue: number;
    interval: number;
    done: boolean;
}

function frame(ctx: IProgressBarCtx) {
    if (ctx.progress >= 100) {
        clearInterval(ctx.interval);
        ctx.interval = 0;
        ctx.progress = 100;
        ctx.data.onDone();
    } else {
        ctx.progress++;
        if (ctx.progress === 100 && ctx.onePercentValue === ctx.data.onePercentValue) {
            ctx.data.onDone();
        }
        b.invalidate(ctx);
    }
}

function startInterval(ctx: IProgressBarCtx) {
    if (ctx.interval) {
        clearInterval(ctx.interval);
        ctx.interval = 0;
        ctx.progress = 100;
        ctx.data.onDone();
    }
    ctx.onePercentValue = ctx.data.onePercentValue;
    if (ctx.onePercentValue !== undefined) {
        ctx.progress = 0;
        ctx.done = false;
        ctx.data.onStarted();
        ctx.interval = setInterval(() => frame(ctx), ctx.onePercentValue * constants.slowedTime);
    }
}

export const progressBar = b.createComponent<IProgressBarData>({
    id: 'progress-bar',
    init(ctx: IProgressBarCtx) {
        ctx.done = false;
        if (ctx.data.onePercentValue !== undefined) {
            ctx.progress = 0;
            ctx.done = false;
        } else {
            ctx.progress = 100;
            ctx.data.onDone();
        }
    },
    render(ctx: IProgressBarCtx, me: b.IBobrilNode) {
        if (ctx.progress <= 100 && ctx.onePercentValue !== ctx.data.onePercentValue) {
            startInterval(ctx);
            ctx.done = false;
        }

        me.children = [
            b.style(
                bs.elem({ tag: 'div' }, [
                    b.style(
                        bs.elem({ tag: 'div' }, []), {
                            width: ctx.progress + '%', height: 10, backgroundColor: colors.defaultBlack
                        })
                ]),
                progressBarStyle)
        ];
        b.style(
            me,
            progressWrapStyle
        );
    }
});