import * as b from 'bobril';
import * as colors from '../../common/colors';

const buttonStyle = b.styleDef({
    border: 'none', color: colors.grayDark, position: 'relative',
    top: 7,
    right: 20,
    cssFloat: 'right'
});

const buttonStyleNoSentences = b.styleDef({
    border: 'none', color: colors.grayDark, position: 'relative',
    top: 7,
    right: 20,
    cssFloat: 'right'
});

const buttonFullStyle = b.styleDef({
    border: 'none', color: colors.grayDark,
    fontSize: 25, position: 'relative',
    top: 10,
    right: 20,
    cssFloat: 'right'
});

const buttonFullStyleNoSentences = b.styleDef({
    border: 'none', color: colors.grayDark,
    fontSize: 25, position: 'relative',
    top: 10,
    right: 20,
    cssFloat: 'right'
});

const sliderHandle = b.styleDef({
    background: colors.redHighlight
});

const sliderWidth = b.styleDef({
    width: 70
});

export interface ISliderData {
    id: string;
    value: number;
    onChanged: (value: number) => void;
    fullScreen: boolean;
    shownSentences: boolean;
    enabled?: boolean;
}

interface ISliderCtx extends b.IBobrilCtx {
    data: ISliderData;
    element: JQuery;
    sliderTime: Slider;
    lastStyle: string;
}

export const slider = b.createComponent<ISliderData>({
    id: 'slider',
    render(ctx: ISliderCtx, me: b.IBobrilNode) {
        me.tag = 'input';
        me.attrs = { id: ctx.data.id, value: ctx.data.value.toString() };
    },
    postInitDom(ctx: ISliderCtx) {
        ctx.sliderTime = new Slider('#' + ctx.data.id, {
            formatter: function (value) {
                return 'Zpomalení: ' + value + 'x';
            },
            id: ctx.data.id + 'div',
            min: 1,
            max: 3,
            value: 1,
            scale: 'linear',
            step: 0.5
        });

        ctx.element = $((ctx.sliderTime as ISliderExt).sliderElem);
        ctx.element.find('.slider-handle').addClass(sliderHandle);
        ctx.element.addClass(sliderWidth);
        $('.slider-horizontal').css('width', '70px');
        ctx.element.addClass(ctx.data.fullScreen ?
            ctx.data.shownSentences ?
                buttonFullStyle
                : buttonFullStyleNoSentences
            : ctx.data.shownSentences ?
                buttonStyle
                : buttonStyleNoSentences);

        ctx.element.on('slide', function (sliderValue) {
            ctx.data.onChanged(<number>sliderValue.value);
        });
    },
    postUpdateDom(ctx: ISliderCtx) {
        ctx.element.removeClass(ctx.lastStyle);
        ctx.lastStyle = ctx.data.fullScreen ?
            ctx.data.shownSentences ?
                buttonFullStyle
                : buttonFullStyleNoSentences
            : ctx.data.shownSentences ?
                buttonStyle
                : buttonStyleNoSentences;
        ctx.element.addClass(ctx.lastStyle);

        ctx.data.enabled ? ctx.sliderTime.enable() : ctx.sliderTime.disable();
    },
    onChange(ctx: ISliderCtx, value: string) {
        ctx.data.onChanged(parseInt(value, 10));
    }

});

interface ISliderExt {
    sliderElem?: HTMLElement;
}