import * as b from 'bobril';
import * as colors from '../../common/colors';
import * as constants from '../../common/constants';
import * as computer from '../../common/computer';

const edgeStyle = b.styleDef({ stroke: colors.defaultBlack, strokeWidth: '3px' });
const dottedEdgeStyle = b.styleDef({
    stroke: colors.defaultBlack, strokeWidth: '5px',
    strokeLinecap: 'round', strokeDasharray: '1, 30'
});

export interface IEdgeData {
    children?: b.IBobrilChildren;
    x1: number;
    y1: number;
    x2: number;
    y2: number;
    color?: string;
    strokeWidth?: number;
    dotted?: boolean;
    moved?: number;
    waitForAnimation?: number; // in miliseconds
    stepIndex?: number;
    oldStepIndex?: number;
}

interface IEdgeCtx extends b.IBobrilCtx {
    data: IEdgeData;
    opac: number;
    myOldStepIndex: number;
    timeout: number;
    inter: number;
    eventListener: () => void;
}

export const edge = b.createComponent<IEdgeData>({
    id: 'edge',
    init(ctx: IEdgeCtx, me: b.IBobrilNode) {
        if (ctx.data.waitForAnimation !== undefined) {
            ctx.opac = 0.005;
        }
    },
    render(ctx: IEdgeCtx, me: b.IBobrilNode) {
        me.tag = 'line';
        me.children = ctx.data.children;

        if (ctx.data.moved !== undefined) {
            let pos = computer.computeMovedPosition(ctx.data.x1, ctx.data.x2, ctx.data.y1, ctx.data.y2, ctx.data.moved);

            me.attrs = {
                x1: pos[0].x, y1: pos[0].y,
                x2: pos[1].x, y2: pos[1].y
            };
        } else {
            me.attrs = {
                x1: ctx.data.x1, y1: ctx.data.y1,
                x2: ctx.data.x2, y2: ctx.data.y2
            };
        }
        b.style(
            me,
            ctx.data.dotted ? dottedEdgeStyle : edgeStyle,
            !!ctx.data.color && { stroke: ctx.data.color },
            !!ctx.data.strokeWidth && { strokeWidth: ctx.data.strokeWidth },
            { opacity: ctx.data.waitForAnimation === undefined ? 1 : ctx.opac }
        );

        function createInterval() {
            ctx.inter = setInterval(
                () => {
                    ctx.opac += (0.04 / constants.slowedTime);
                    b.invalidate(ctx);
                    if (Math.floor(ctx.opac) === 1) {
                        document.body.removeEventListener('finish-animation', ctx.eventListener, false);
                        clearTimeout(ctx.timeout);
                        ctx.timeout = 0;
                        clearInterval(ctx.inter);
                        ctx.inter = 0;
                    }
                },
                100);
        }

        if (ctx.opac === 0.005 && !ctx.timeout) {
            ctx.timeout = setTimeout(createInterval, ctx.data.waitForAnimation * constants.slowedTime);

            ctx.eventListener = () => {
                ctx.opac = 1;
                clearTimeout(ctx.timeout);
                ctx.timeout = 0;
                clearInterval(ctx.inter);
                ctx.inter = 0;
                document.body.removeEventListener('finish-animation', ctx.eventListener, false);
                b.invalidate(ctx);
            };

            document.body.addEventListener('finish-animation', ctx.eventListener, false);
        }

        ctx.myOldStepIndex = ctx.data.stepIndex;
    }
});