import * as b from 'bobril';
import * as colors from '../../common/colors';

const vertexStyle = b.styleDef({ stroke: colors.defaultBlack, strokeWidth: '3px', fill: colors.defaultVertex });

export interface IVertexData {
    children?: b.IBobrilChildren;
    cx: number;
    cy: number;
    r: number;
    onMove?: (dx: number, dy: number) => void;
    color?: string;
    strokeColor?: string;
    strokeWidth?: number;
}

interface IVertexCtx extends b.IBobrilCtx {
    data: IVertexData;
    lastX: number;
    lastY: number;
    timeout: number;
}

export const vertex = b.createComponent<IVertexData>({
    id: 'vertex',
    render(ctx: IVertexCtx, me: b.IBobrilNode) {
        me.tag = 'circle';
        me.children = ctx.data.children;

        if (ctx.data.cx <= 0) {
            ctx.data.cx = 0;
        }

        if (ctx.data.cy <= 0) {
            ctx.data.cy = 0;
        }

        me.attrs = { cx: ctx.data.cx, cy: ctx.data.cy, r: ctx.data.r };
        b.style(
            me, vertexStyle,
            !!ctx.data.color && { fill: ctx.data.color },
            !!ctx.data.strokeColor && { stroke: ctx.data.strokeColor },
            !!ctx.data.strokeWidth && { strokeWidth: ctx.data.strokeWidth });
    },
    onPointerDown(ctx: IVertexCtx, param: b.IBobrilPointerEvent) {
        b.registerMouseOwner(ctx);
        let svgCircle = <SVGCircleElement>ctx.me.element;
        let svg = svgCircle.ownerSVGElement;
        let point = svg.createSVGPoint();
        point.x = param.x;
        point.y = param.y;
        let ctm = svgCircle.getScreenCTM();
        point = point.matrixTransform(ctm.inverse());

        ctx.lastX = point.x;
        ctx.lastY = point.y;
        return true;
    },
    onPointerMove(ctx: IVertexCtx, param: b.IBobrilPointerEvent) {
        if (!b.isMouseOwner(ctx)) {
            return false;
        }

        let svgCircle = <SVGCircleElement>ctx.me.element;
        let svg = svgCircle.ownerSVGElement;
        let point = svg.createSVGPoint();
        point.x = param.x;
        point.y = param.y;
        let ctm = svgCircle.getScreenCTM();
        point = point.matrixTransform(ctm.inverse());

        if ((ctx.lastX === point.x && ctx.lastY === point.y) ||
            point.x <= 0 ||
            point.y <= 0 ||
            point.x >= svg.getBoundingClientRect().width ||
            point.y >= svg.getBoundingClientRect().height
        ) {
            return false;
        }

        if (ctx.data.onMove) {
            ctx.data.onMove(point.x - ctx.lastX, point.y - ctx.lastY);
        }

        ctx.lastX = point.x;
        ctx.lastY = point.y;
        return true;
    },
    onPointerUp(ctx: IVertexCtx, param: b.IBobrilPointerEvent) {
        b.releaseMouseOwner();
        return true;
    },
    onPointerCancel(ctx: IVertexCtx, param: b.IBobrilPointerEvent) {
        return true;
    }
});