import * as b from 'bobril';
import * as constants from '../../common/constants';

export interface IImageData {
    children?: b.IBobrilChildren;
    x: number;
    y: number;
    width: number;
    type: string;
    height?: number;
    waitForAnimation?: number; // in miliseconds
}

interface IImageCtx extends b.IBobrilCtx {
    data: IImageData;
    opac: number;
    timeout: number;
    removeElement: () => void;
    inter: number;
    eventListener: () => void;
}

const path = b.asset('../../images/chocolate.png');
const path2 = b.asset('../../images/student.png');
const pathHamburger = b.asset('../../images/hamburger.png');
const pathBeer = b.asset('../../images/beer2.png');
const pathBeerNo = b.asset('../../images/beer3.png');

export const image = b.createVirtualComponent<IImageData>({
    id: 'image',
    init(ctx: IImageCtx, me: b.IBobrilNode) {
        if (ctx.data.waitForAnimation !== undefined) {
            ctx.opac = 0.005;
        }
    },
    render(ctx: IImageCtx, me: b.IBobrilNode) {
        me.tag = 'image';
        me.children = ctx.data.children;
        switch (ctx.data.type) {
            case 'chocolate':
                me.attrs = { 'href': path, x: ctx.data.x, y: ctx.data.y, width: ctx.data.width, height: ctx.data.height };
                break;
            case 'student':
                me.attrs = { 'href': path2, x: ctx.data.x, y: ctx.data.y, width: ctx.data.width, height: ctx.data.height };
                break;
            case 'hamburger':
                me.attrs = { 'href': pathHamburger, x: ctx.data.x, y: ctx.data.y, width: ctx.data.width, height: ctx.data.height };
                break;
            case 'beer':
                me.attrs = { 'href': pathBeer, x: ctx.data.x, y: ctx.data.y, width: ctx.data.width, height: ctx.data.height };
                break;
            case 'beerNo':
                me.attrs = { 'href': pathBeerNo, x: ctx.data.x, y: ctx.data.y, width: ctx.data.width, height: ctx.data.height };
                break;

            default:
                me.attrs = { 'href': path, x: ctx.data.x, y: ctx.data.y, width: ctx.data.width, height: ctx.data.height };
                break;
        }
        b.style(
            me,
            { opacity: ctx.data.waitForAnimation === undefined ? 1 : ctx.opac }
        );

        function createInterval() {
            ctx.inter = setInterval(
                () => {
                    ctx.opac += (0.04 / constants.slowedTime);
                    b.invalidate(ctx);
                    if (Math.floor(ctx.opac) === 1) {
                        document.body.removeEventListener('finish-animation', ctx.eventListener, false);
                        clearTimeout(ctx.timeout);
                        ctx.timeout = 0;
                        clearInterval(ctx.inter);
                        ctx.inter = 0;
                    }
                },
                100);
        }

        if (ctx.opac === 0.005 && !ctx.timeout) {
            ctx.timeout = setTimeout(createInterval, ctx.data.waitForAnimation * constants.slowedTime);

            ctx.eventListener = () => {
                ctx.opac = 1;
                clearTimeout(ctx.timeout);
                ctx.timeout = 0;
                clearInterval(ctx.inter);
                ctx.inter = 0;
                document.body.removeEventListener('finish-animation', ctx.eventListener, false);
                b.invalidate(ctx);
            };

            document.body.addEventListener('finish-animation', ctx.eventListener, false);
        }
    },
});