import * as b from 'bobril';
import * as colors from '../../common/colors';
import { definition } from './definition';
import { chosenDefinition } from './chosenDefinition';
import { IDefinition } from '../../model/IDefinition';

const definitionStyle = b.styleDef({
    color: colors.defaultBlack,
    backgroundColor: colors.defaultWhite,
    strokeOpacity: 0.4,
    height: '100%',
    border: '1px solid ' + colors.grayDarkerLight,
    padding: 15,
    overflowY: 'auto',
    direction: 'rtl',
});

export interface IDefinitionsData {
    defs: IDefinition[];
    step: number;
}

interface IDefinitionsCtx extends b.IBobrilCtx {
    data: IDefinitionsData;
    indexOfChosen: number;
    lastIndexOfChosen: number;
    inter: number;
    manualScroll: boolean;
}

export const definitions = b.createComponent<IDefinitionsData>({
    id: 'definitions',
    render(ctx: IDefinitionsCtx, me: b.IBobrilNode) {
        let listChildren: b.IBobrilChildren = [];
        b.style(
            me,
            definitionStyle
        );

        ctx.lastIndexOfChosen = ctx.indexOfChosen;

        if (ctx.data.defs !== undefined) {
            for (let i = 0; i < ctx.data.defs.length; i++) {
                if (ctx.data.defs[i].text !== undefined) {
                    if (ctx.data.step === i) {
                        ctx.indexOfChosen = i;
                        listChildren[i] = chosenDefinition({
                            color: ctx.data.defs[i].color,
                            text: ctx.data.defs[i].text,
                            nesting: ctx.data.defs[i].nesting
                        });
                    } else {
                        listChildren[i] = definition({
                            color: ctx.data.defs[i].color,
                            text: ctx.data.defs[i].text,
                            nesting: ctx.data.defs[i].nesting
                        });
                    }
                }
            }
        }
        me.children = listChildren;
    },
    postInitDom(ctx: IDefinitionsCtx, me: b.IBobrilNode, element: HTMLElement) {
        element.onscroll = () => {
            if (!ctx.inter) {
                ctx.manualScroll = true;
            }
        };

    },
    postUpdateDom(ctx: IDefinitionsCtx) {
        if (ctx.lastIndexOfChosen !== ctx.indexOfChosen) {

            let el = <HTMLDivElement>ctx.me.element;

            let chosen = ctx.me.children[ctx.indexOfChosen];
            let el2 = <HTMLDivElement>b.getDomNode(<b.IBobrilCacheNode>chosen);

            if (!ctx.manualScroll && !ctx.inter) {
                let chosenBefore = ctx.me.children[ctx.lastIndexOfChosen];
                let elBefore = <HTMLDivElement>b.getDomNode(<b.IBobrilCacheNode>chosenBefore);
                elBefore.scrollIntoView();
            }

            performAnimations(ctx, el, el2);
        }
    }
});

function performAnimations(ctx: IDefinitionsCtx, container: HTMLElement, definition: HTMLElement, interval: number = 20) {
    if (ctx.inter !== undefined) {
        clearInterval(ctx.inter);
        ctx.inter = undefined;
    }

    ctx.inter = setInterval(
        () => {
            ctx.manualScroll = false;
            const diff = Math.round(container.scrollTop) - Math.round(definition.offsetTop);
            if (!diff) {
                clearInterval(ctx.inter);
                ctx.inter = undefined;
            } else if (diff > 0) {
                if (diff > 100) {
                    container.scrollTop -= 2;
                }
                container.scrollTop--;
                b.invalidate(ctx);
                checkSpeed(ctx, interval, diff, container, definition);
            } else if (diff < 0) {
                if (container.scrollTop >= container.scrollHeight - container.getBoundingClientRect().height) {
                    clearInterval(ctx.inter);
                    ctx.inter = undefined;
                }
                if (diff < -100) {
                    container.scrollTop += 2;
                }
                container.scrollTop++;
                b.invalidate(ctx);
                checkSpeed(ctx, interval, diff, container, definition);
            }

        },
        interval);
}

function checkSpeed(ctx: IDefinitionsCtx, currentInterval: number, diff: number, container: HTMLElement, definition: HTMLElement) {
    let interval = 20;
    const absDiff = Math.abs(diff);
    if (absDiff > 80){
        interval = 1;
    } else if (absDiff > 20) {
        interval = 5;
    } else if (absDiff > 15) {
        interval = 8;
    } else if (absDiff > 10) {
        interval = 12;
    } else if (absDiff > 5) {
        interval = 15;
    }

    if (currentInterval === interval)
        return;

    performAnimations(ctx, container, definition, interval);
}