import * as b from 'bobril';
import * as bs from 'bobrilstrap';
import * as css from '../theme/css/css';
import { vertex } from './vertex';
import * as colors from '../common/colors';

const vertexInvisibleStyle = b.styleDef({ stroke: colors.defaultBlack, strokeWidth: '3px', opacity: 0.001 });

export interface IDrawPathData {
    children?: b.IBobrilChildren;
}

export interface IDrawPathCtx extends b.IBobrilCtx {
    data: IDrawPathData;
    startX: number;
    startY: number;
    lastX: number;
    lastY: number;
    journey: string;
}

export const drawPathOld = b.createComponent({
    init(ctx: IDrawPathCtx) {
        ctx.journey = '';
    },
    render(ctx: IDrawPathCtx, me: b.IBobrilNode) {
        me.tag = 'svg';
        b.style(me, css.canvas);
        me.children = [
            b.style(vertex({ cx: 0, cy: 0, r: 5 }, []), vertexInvisibleStyle),
            b.style(
                bs.elem(
                    {
                        tag: 'path', attrs: { d: ctx.journey, stroke: colors.defaultBlack, strokeWidth: 2, fill: 'None' }
                    },
                    []),
                { strokeWidth: '2px' }
            ),
        ];
        ctx.data.children = me.children;
    },
    onPointerDown(ctx: IDrawPathCtx, param: b.IBobrilPointerEvent): boolean {
        b.registerMouseOwner(ctx);
        let svg = <SVGSVGElement>ctx.me.element;
        let svgCircle = <SVGCircleElement>svg.firstChild;
        let point = svg.createSVGPoint();
        point.x = param.x;
        point.y = param.y;
        let ctm = svgCircle.getScreenCTM();
        point = point.matrixTransform(ctm.inverse());

        ctx.startX = point.x;
        ctx.startY = point.y;
        ctx.lastX = point.x;
        ctx.lastY = point.y;
        ctx.journey = ctx.journey.concat('M' + ' ' + point.x + ' ' + point.y + ' ');
        b.invalidate();
        return true;
    },
    onPointerMove(ctx: IDrawPathCtx, param: b.IBobrilPointerEvent): boolean {
        if (!b.isMouseOwner(ctx)) {
            return false;
        }

        if (ctx.journey === '') {
            return;
        }

        let svg = <SVGSVGElement>ctx.me.element;
        let svgCircle = <SVGCircleElement>svg.firstChild;
        let point = svg.createSVGPoint();
        point.x = param.x;
        point.y = param.y;
        let ctm = svgCircle.getScreenCTM();
        point = point.matrixTransform(ctm.inverse());

        if (ctx.lastX === point.x || ctx.lastY === point.y) {
            return false;
        }

        ctx.journey = ctx.journey.concat('L' + ' ' + point.x + ' ' + point.y + ' ');
        ctx.lastX = point.x;
        ctx.lastY = point.y;
        b.invalidate();
        return true;
    },
    onPointerUp(ctx: IDrawPathCtx, param: b.IBobrilPointerEvent) {
        b.releaseMouseOwner();
        return true;
    },
    onPointerCancel(ctx: IDrawPathCtx, param: b.IBobrilPointerEvent): boolean {
        return true;
    }
});