import * as b from 'bobril';
import * as bs from 'bobrilstrap';
import * as css from '../../theme/css/css';
import { cloudFilter } from '../graph/cloudFilter';
import { vertex } from '../graph/vertex';
import * as colors from '../../common/colors';

const vertexInvisibleStyle = b.styleDef({ stroke: colors.defaultWhite, strokeWidth: '3px', opacity: 0.001 });

export interface ISvgData {
    children?: b.IBobrilChildren;
    fullScreen: boolean;
    negations?: boolean;
    journey: string;
    onJourneyChanged: (journey: string) => void;
    shownSentences: boolean;
}

export interface ISvgCtx extends b.IBobrilCtx {
    data: ISvgData;
    startX: number;
    startY: number;
    lastX: number;
    lastY: number;
}

export const svg = b.createComponent({
    render(ctx: ISvgCtx, me: b.IBobrilNode, oldMe?: b.IBobrilCacheNode): void {
        me.tag = 'svg';
        me.children =
            [
                b.style(vertex({ cx: 0, cy: 0, r: 5 }, []), vertexInvisibleStyle),
                cloudFilter(),
                ctx.data.children,
                !!ctx.data.journey && b.style(
                    bs.elem(
                        {
                            tag: 'path', attrs: {
                                d: ctx.data.journey,
                                stroke: colors.orangeHighlight, fill: 'None', filter: 'url(#filterPath)'
                            }
                        },
                        []),
                    { strokeWidth: '3px' }
                )];
        me.attrs = { viewBox: '0 0 800 500' };
        b.style(me, ctx.data.fullScreen ?
            ctx.data.negations ? css.negationsCanvasWindow : ctx.data.shownSentences ? css.canvasWindow : css.canvasWindowNoSentences :
            ctx.data.negations ? css.negationsCanvas : ctx.data.shownSentences ? css.canvas : css.canvasNoSentences);
    },
    onPointerDown(ctx: ISvgCtx, param: b.IBobrilPointerEvent): boolean {
        b.registerMouseOwner(ctx);
        let svgEl = <SVGSVGElement>ctx.me.element;
        let svgCircle = <SVGCircleElement>svgEl.firstChild;
        let point = svgEl.createSVGPoint();
        point.x = param.x;
        point.y = param.y;
        let ctm = svgCircle.getScreenCTM();
        point = point.matrixTransform(ctm.inverse());

        ctx.startX = point.x;
        ctx.startY = point.y;
        ctx.lastX = point.x;
        ctx.lastY = point.y;
        ctx.data.onJourneyChanged((ctx.data.journey || '').concat('M' + ' ' + point.x + ' ' + point.y + ' '));
        b.invalidate();
        return true;
    },
    onPointerMove(ctx: ISvgCtx, param: b.IBobrilPointerEvent): boolean {
        if (!b.isMouseOwner(ctx)) {
            return false;
        }

        if (ctx.data.journey === '' || !ctx.data.journey) {
            return;
        }

        let svgEl = <SVGSVGElement>ctx.me.element;
        let svgCircle = <SVGCircleElement>svgEl.firstChild;
        let point = svgEl.createSVGPoint();
        point.x = param.x;
        point.y = param.y;
        let ctm = svgCircle.getScreenCTM();
        point = point.matrixTransform(ctm.inverse());

        if (ctx.lastX === point.x || ctx.lastY === point.y) {
            return false;
        }

        ctx.data.onJourneyChanged(ctx.data.journey.concat('L' + ' ' + point.x + ' ' + point.y + ' '));
        ctx.lastX = point.x;
        ctx.lastY = point.y;
        b.invalidate();
        return true;
    },
    onPointerUp(ctx: ISvgCtx, param: b.IBobrilPointerEvent) {
        b.releaseMouseOwner();
        b.invalidate();
        return true;
    },
    onPointerCancel(ctx: ISvgCtx, param: b.IBobrilPointerEvent): boolean {
        return true;
    }
});