import * as b from 'bobril';
import * as colors from '../../common/colors';
import * as constants from '../../common/constants';

const whiteboardStyle = b.styleDef({
    color: colors.defaultBlack,
    position: 'absolute',
    top: 200,
    left: 0,
    fontSize: '19px'
});

const whiteboardFullStyle = b.styleDef({
    color: colors.defaultBlack,
    position: 'absolute',
    top: 200,
    left: 0,
    fontSize: '26px'
});

export interface IWhiteboardData {
    children?: b.IBobrilChildren;
    top?: number;
    left?: number;
    countedTop?: number;
    countedLeft?: number;
    oldCountedTop?: number;
    oldCountedLeft?: number;
    color?: string;
    backgroundColor?: string;
    margin?: number;
    waitForAnimation?: number; // in miliseconds
    fullScreen: boolean;
    fontSize?: number;
}

interface IWhiteboardCtx extends b.IBobrilCtx {
    data: IWhiteboardData;
    opac: number;
    newHeight: number;
    newWidth: number;
    oldHeight: number;
    oldWidth: number;
    oldFullScreen: boolean;
    timeout: number;
    inter: number;
    eventListener: () => void;
}

export const whiteboard = b.createComponent<IWhiteboardData>({
    id: 'whiteboard',
    init(ctx: IWhiteboardCtx, me: b.IBobrilNode) {
        if (ctx.data.waitForAnimation !== undefined) {
            ctx.opac = 0.005;
        }
    },
    render(ctx: IWhiteboardCtx, me: b.IBobrilNode) {
        me.children = ctx.data.children;
        b.style(
            me,
            ctx.data.fullScreen ? whiteboardFullStyle : whiteboardStyle,
            !!ctx.data.top && { top: ctx.data.countedTop },
            !!ctx.data.left && { left: ctx.data.countedLeft },
            !!ctx.data.color && { color: ctx.data.color },
            !!ctx.data.backgroundColor && { backgroundColor: ctx.data.backgroundColor },
            !!ctx.data.fontSize && { fontSize: ctx.data.fullScreen ? ctx.data.fontSize * 1.36 : ctx.data.fontSize },
            !!ctx.data.margin && { margin: ctx.data.margin },
            { opacity: ctx.data.waitForAnimation === undefined ? 1 : ctx.opac }
        );
        function createInterval() {
            ctx.inter = setInterval(
                () => {
                    ctx.opac += (0.04 / constants.slowedTime);
                    b.invalidate(ctx);
                    if (Math.floor(ctx.opac) === 1) {
                        document.body.removeEventListener('finish-animation', ctx.eventListener, false);
                        clearTimeout(ctx.timeout);
                        ctx.timeout = 0;
                        clearInterval(ctx.inter);
                        ctx.inter = 0;
                    }
                },
                100);
        }

        if (ctx.opac === 0.005 && !ctx.timeout) {
            ctx.timeout = setTimeout(createInterval, ctx.data.waitForAnimation * constants.slowedTime);

            ctx.eventListener = () => {
                ctx.opac = 1;
                clearTimeout(ctx.timeout);
                ctx.timeout = 0;
                clearInterval(ctx.inter);
                ctx.inter = 0;
                document.body.removeEventListener('finish-animation', ctx.eventListener, false);
                b.invalidate(ctx);
            };

            document.body.addEventListener('finish-animation', ctx.eventListener, false);
        }

        ctx.oldHeight = ctx.newHeight;
        ctx.oldWidth = ctx.newWidth;
    }
});