import * as b from 'bobril';
import * as bs from 'bobrilstrap';

const imageStyle = b.styleDef({
    marginLeft: 'auto',
    marginRight: 'auto',
    marginTop: 30,
    marginBottom: 30,
    display: 'block'
});

const path2 = b.asset('../images/docNegace2.png');
const path3 = b.asset('../images/docNegace3.png');
const path5 = b.asset('../images/vizualizace1.png');

export const prirucka = b.createVirtualComponent({
    render(ctx: b.IBobrilCtx, me: b.IBobrilNode) {
        me.children = [
            bs.h2({}, 'Uživatelská příručka'),

            bs.h3({}, 'Obsah'),
            b.link(bs.a({}, 'O aplikaci'), 'priruckaUvod'),
            bs.elem({ tag: 'br' }),
            b.link(bs.a({}, 'Požadavky na konfiguraci'), 'priruckaSystem'),
            bs.elem({ tag: 'br' }),
            b.link(bs.a({}, 'Složení aplikace'), 'priruckaAplikace'),
            bs.elem({ tag: 'br' }),
            b.link(bs.a({}, 'Výroková logika'), 'priruckaVyroky'),
            bs.elem({ tag: 'br' }),
            b.link(bs.a({}, 'Typy důkazů'), 'priruckaTypy'),
            bs.elem({ tag: 'br' }),
            b.link(bs.a({}, 'Důkazy'), 'priruckaDukazy'),
            bs.elem({ tag: 'br' }),
            b.link(bs.a({}, 'FAQ'), 'priruckaFAQ'),

            b.anchor(bs.h3({ attrs: { id: 'priruckaUvod' } }, 'O aplikaci')),
            bs.paragraph({}, ['Aplikace GraPro (zkratka ze slov graph proofs, tedy důkazy grafů) slouží k výuce důkazů v teorii grafů. V aplikaci je možné ',
                'procházet teoretické základy nutné k pochopení důkazů. Aplikace obsahuje vizualizace ',
                'negací a důkazů, se kterými se dá interaktivně pracovat. Také je ',
                'možné si negace procvičit. Aplikaci lze spouštět lokálně nebo je možné ji umístit na server.']),

            b.anchor(bs.h3({ attrs: { id: 'priruckaSystem' } }, 'Požadavky na konfiguraci')),
            bs.paragraph({}, ['Aplikace nemá výraznější požadavky na konfiguraci systému z hlediska výkonu. ',
                'Pro nejlepší uživatelskou zkušenost je doporučeno spouštět aplikaci v prohlížeči ',
                'Google Chrome, popřípadě Mozilla Firefox, a to v nejnovějších verzích prohlížečů. ',
                'Minimální rozlišení obrazovky by mělo být 1024x768. ']),

            bs.paragraph({}, ['Aplikace funguje i na mobilních zařízeních. V tomto případě je doporučen prohlížeč',
                ' Google Chrome, Firefox Focus nebo Safari. V těchto prohlížečích by se webová stránka měla ',
                'přizpůsobit velikosti displeje a žádná funkcionalita by neměla být omezena. Přesto je ',
                'doporučeno aplikaci používat minimálně na zařízeních velikosti tabletu, aby bylo možné ji pohodlně ovládat. ']),

            b.anchor(bs.h3({ attrs: { id: 'priruckaAplikace' } }, 'Složení aplikace')),
            bs.paragraph({}, ['Aplikace se skládá ze tří hlavních částí:']),
            bs.ul({}, [
                bs.li({}, ['Výroková logika - tato část obsahuje základní teoretický úvod do této oblasti, ',
                    'který je nutný pro pochopení principu matematických důkazů.']),
                bs.li({}, ['Typy důkazů - zde jsou představeny základní typy matematických důkazů.']),
                bs.li({}, ['Důkazy - tato část obsahuje samotné vizualizace vybraných důkazů z teorie grafů.'])
            ]),

            b.anchor(bs.h3({ attrs: { id: 'priruckaVyroky' } }, 'Výroková logika')),
            bs.paragraph({}, ['Tato část obsahuje šest podčástí: ']),
            bs.ul({}, [
                bs.li({}, ['Výroky']),
                bs.li({}, ['Kvantifikované výroky']),
                bs.li({}, ['Vizualizace negací']),
                bs.li({}, ['Složené výroky']),
                bs.li({}, ['Matematické věty']),
                bs.li({}, ['Procvičení']),
            ]),
            bs.paragraph({}, ['Části s vizualizacemi a procvičením negací jsou interaktivní, proto se jim bude příručka věnovat více.']),

            b.anchor(bs.h4({ attrs: { id: 'priruckaVizualizaceNegaci' } }, 'Vizualizace negací')),
            bs.paragraph({}, ['V této části je možné si interaktivně projít vizualizace negování čtyř typů ',
                'kvantifikovaných výroků, které by měly usnadnit pochopení negací těchto výroků. ']),
            b.style(bs.image({ src: path2 }, []), imageStyle),

            bs.paragraph({}, ['Obrazovka vizualizace obsahuje několik ovládacích prvků: ']),
            bs.ul({}, [
                bs.li({}, ['Tlačítka pro pohyb zpět a vpřed']),
                bs.li({}, ['Tlačítko pro návrat na první krok']),
                bs.li({}, ['Tlačítko pro mazání nakreslených tvarů']),
                bs.li({}, ['Tlačítka 1-4 pro přechod na další typy kvantifikovaných výroků']),
                bs.li({}, ['Tlačítko pro zvětšení na celou obrazovku']),
            ]),
            bs.paragraph({}, ['Na zobrazovací plochu je možné kreslit oranžovým perem, což může být užitečné ',
                'zejména pro vyučujícího při výuce: ']),
            b.style(bs.image({ src: path3 }, []), imageStyle),

            b.anchor(bs.h3({ attrs: { id: 'priruckaTypy' } }, 'Typy důkazů')),
            bs.paragraph({}, ['Tato část obsahuje teoretické představení obecných typů matematických důkazů. ']),

            b.anchor(bs.h3({ attrs: { id: 'priruckaDukazy' } }, 'Důkazy')),
            bs.paragraph({}, ['V této části jsou vizualizace vybraných důkazů z teorie grafů, ',
                'jako je například princip sudosti a další. ']),
            b.style(bs.image({ src: path5 }, []), imageStyle),
            bs.paragraph({}, ['"Přehrávač" důkazů obsahuje kroky důkazu na levé straně, hlavní vykreslovací ',
                'plochu na pravé straně a tlačítko pro zobrazení definic a dalších pomocných informací, ',
                'které se zobrazují pod hlavní obrazovkou. S prvky jako jsou vrcholy a barevné tipy lze hýbat s pomocí myši. ']),
            bs.paragraph({}, ['Obrazovka vizualizace důkazů obsahuje několik ovládacích prvků: ']),
            bs.ul({}, [
                bs.li({}, ['Tlačítko pro opakování animace v daném kroku důkazu']),
                bs.li({}, ['Tlačítka pro pohyb zpět a vpřed']),
                bs.li({}, ['Ukazatel průběhu animace']),
                bs.li({}, ['Tlačítko pro návrat na první krok']),
                bs.li({}, ['Tlačítko pro mazání nakreslených tvarů']),
                bs.li({}, ['Tlačítko pro zvětšení na celou obrazovku']),
                bs.li({}, ['Posuvník pro zpomalení animace']),
            ]),

            b.anchor(bs.h3({ attrs: { id: 'priruckaFAQ' } }, 'FAQ')),
            bs.paragraph({}, ['Co dělat, když se nějaký prvek špatně zobrazí? ',
                bs.elem({ tag: 'br' }, []), 'Jako první pomoc použijte obnovení stránky klávesou F5, popřípadě CTRL + F5. ']),
            bs.paragraph({}, ['Co dělat, když nefunguje ovládání vizualizace? ',
                bs.elem({ tag: 'br' }, []), 'Nejdřív zkontrolujte použitý prohlížeč, aplikace se doporučuje pouštět v Google Chrome. ']),
            bs.paragraph({}, ['Co dělat, když najdu bug? ',
                bs.elem({ tag: 'br' }, []), 'V případě problémů kontaktujte autorku, kontakt je na úvodní straně. ']),
        ];
    }
});