import * as b from 'bobril';
import * as bs from 'bobrilstrap';
import * as a from '../../viewer/actions';
import * as colors from '../../common/colors';

export const examples = () => [
    {
        name: 'tvrzeni1',
        definitions: [
            {
                nesting: 0,
                color: colors.orangeHighlight,
                text: [
                    'Tvrzení: V grafu existuje cesta z ',
                    bs.em({}, 'v'),
                    ' do ',
                    bs.em({}, 'w'),
                    ' právě tehdy, když existuje sled z ',
                    bs.em({}, 'v'),
                    ' do ',
                    bs.em({}, 'w'),
                    '.'
                ]
            },
            {
                nesting: 0,
                color: colors.orangeHighlight,
                text: [
                    'Rozdělení věty na dva výroky ',
                    bs.em({}, 'A'),
                    ' a ',
                    bs.em({}, 'B'),
                    ' spojené pomocí ekvivalence. '
                ]
            },
            {
                nesting: 0,
                color: colors.orangeHighlight,
                text: 'Ekvivalenci dokážeme rozdělením na dvě implikace. '
            },
            {
                nesting: 0,
                color: colors.redHighlight,
                text: [
                    '1. implikace: Jestliže existuje cesta z vrcholu ',
                    bs.em({}, 'v'),
                    ' do vrcholu ',
                    bs.em({}, 'w'),
                    ', pak v ',
                    bs.em({}, 'G'),
                    ' existuje sled z vrcholu ',
                    bs.em({}, 'v'),
                    ' do vrcholu ',
                    bs.em({}, 'w'),
                    '.'
                ]
            },
            {
                nesting: 1,
                color: colors.redHighlightLight,
                text: 'Dle definice cesty je každá cesta zároveň sled. ' +
                'Dokázali jsme první implikaci. '
            },
            {
                nesting: 0,
                color: colors.greenHighlight,
                text: [
                    '2. implikace: ',
                    'Jestliže existuje sled z vrcholu ',
                    bs.em({}, 'v'),
                    ' do vrcholu ',
                    bs.em({}, 'w'),
                    ', ',
                    'pak v G existuje cesta z vrcholu ',
                    bs.em({}, 'v'),
                    ' do vrcholu ',
                    bs.em({}, 'w'),
                    '.'
                ],
            },
            {
                nesting: 1,
                color: colors.greenHighlight,
                text: [
                    'Nakreslíme sled z vrcholu ',
                    bs.em({}, 'v'),
                    ' do vrcholu ',
                    bs.em({}, 'w'),
                ],
            },
            {
                nesting: 1,
                color: colors.greenHighlightLight,
                text: [
                    'Uvažujeme jeho podsled ',
                    bs.em({}, ['S',
                        bs.sub({}, 'min')]),
                    ' z ',
                    bs.em({}, 'v'),
                    ' do ',
                    bs.em({}, 'w'),
                    ' minimální délky.',
                    ' Dokážeme, že ',
                    bs.em({}, ['S',
                        bs.sub({}, 'min')]),
                    ' je cesta z ',
                    bs.em({}, 'v'),
                    ' do ',
                    bs.em({}, 'w'),
                    '.'
                ],
            },
            {
                nesting: 1,
                color: colors.greenHighlightLight,
                text: [
                    ' Důkaz sporem:',
                    ' Existuje sled ',
                    bs.em({}, ['S',
                        bs.sub({}, 'min')]),
                    ' minimální délky z ',
                    bs.em({}, 'v'),
                    ' do ',
                    bs.em({}, 'w'),
                    ' a zároveň ',
                    bs.em({}, ['S',
                        bs.sub({}, 'min')]),
                    ' není cesta z ',
                    bs.em({}, 'v'),
                    ' do ',
                    bs.em({}, 'w'),
                    '.'
                ],
            },
            {
                nesting: 1,
                color: colors.greenHighlightLight,
                text: [
                    'Nakreslíme "minimální" sled, který není cesta. ',
                ],
            },
            {
                nesting: 1,
                color: colors.greenHighlightLight,
                text: [
                    ' Jestliže ',
                    bs.em({}, ['S',
                        bs.sub({}, 'min')]),
                    ' není cesta, pak ',
                    bs.em({}, ['S',
                        bs.sub({}, 'min')]),
                    ' obsahuje',
                    ' alespoň jeden vrchol ',
                    bs.em({}, 'x'),
                    ', který se v ',
                    bs.em({}, ['S',
                        bs.sub({}, 'min')]),
                    ' vyskytuje alespoň dvakrát.'
                ],
            },
            {
                nesting: 1,
                color: colors.greenHighlightLight,
                text: [
                    ' Odebráním posloupnosti od ',
                    bs.em({}, 'x'),
                    ' po další výskyt ',
                    bs.em({}, 'x'),
                    ' dostaneme také sled',
                    ' z vrcholu do ',
                    bs.em({}, 'v'),
                    ' vrcholu ',
                    bs.em({}, 'w'),
                    ', který je ale kratší délky než ',
                    bs.em({}, ['S',
                        bs.sub({}, 'min')]),
                    ',',
                    ' což je spor s předpokladem. Dokázali jsme druhou implikaci. '
                ]
            }
        ],
        steps: [
            {
                actions: [
                    a.addWhiteboard(
                        'whiteboard1',
                        { x: 0, y: 50 },
                        ['Pro každý graf ', bs.em({}, 'G'), '=', bs.em({}, '(V, E)'), ' platí: '],
                        undefined,
                        undefined,
                        40,
                        0
                    ),
                    a.addWhiteboard(
                        'whiteboard1.2',
                        { x: 0, y: 110 },
                        ['V grafu ', bs.em({}, 'G'), ' existuje cesta z vrcholu ', bs.em({}, 'v'),
                            ' do vrcholu ', bs.em({}, 'w')],
                        undefined,
                        undefined,
                        40,
                        1500
                    ),
                    a.addWhiteboard(
                        'whiteboard1.3',
                        { x: 0, y: 170 },
                        [bs.strong({}, [' právě tehdy, když '])],
                        undefined,
                        undefined,
                        40,
                        2250
                    ),
                    a.addWhiteboard(
                        'whiteboard1.4',
                        { x: 0, y: 230 },
                        ['v grafu ', bs.em({}, 'G'), ' existuje sled ' +
                            'z vrcholu ', bs.em({}, 'v'), ' do vrcholu ', bs.em({}, 'w'), '.'],
                        undefined,
                        undefined,
                        40,
                        3000
                    ),
                ],
                sentence: {
                    text: [
                        bs.strong({}, 'Sled'), ' je posloupnost vrcholů a hran ', bs.em({}, ['(v', bs.sub({}, '0'), ', e',
                            bs.sub({}, '1'), ', v', bs.sub({}, '1'), ', ..., e', bs.sub({}, 'k'), ', v', bs.sub({}, 'k'), ')']),
                        ' kde ',
                        bs.em({}, ['e', bs.sub({}, 'i'), ' ']),
                        '= ',
                        bs.em({}, ['{v', bs.sub({}, 'i-1'), ', v', bs.sub({}, 'i'), '}, i ']), '=', bs.em({}, [' 1,..., k']),
                        bs.e({ tag: 'br' }),
                        '\u2022 Hrany a vrcholy se ', bs.strong({}, 'mohou'), ' opakovat',
                        bs.e({ tag: 'br' }),
                        bs.strong({}, 'Cesta'), ' je sled s navzájem různými vrcholy, tj. pro ',
                        bs.em({}, 'i '), '\u2260', bs.em({}, ' j'), ' platí ',
                        bs.em({}, [
                            'v', bs.sub({}, 'i'), ' \u2260 v', bs.sub({}, 'j')
                        ]),
                        bs.e({ tag: 'br' }),
                        '\u2022 Hrany a vrcholy se ', bs.strong({}, 'nesmí'), ' opakovat',
                    ]
                },
                time: 5374
            },
            {
                actions: [
                    a.editWhiteboard(
                        'whiteboard1.2',
                        undefined,
                        [b.style(bs.element({ tag: 'span' }, [
                            'V grafu ',
                            bs.em({}, 'G'),
                            ' existuje cesta z vrcholu ',
                            bs.em({}, 'v'),
                            ' do vrcholu ', bs.em({}, 'w'),
                        ]), { color: colors.redHighlight })],
                    ),
                    a.editWhiteboard(
                        'whiteboard1.4',
                        undefined,
                        [b.style(bs.element({ tag: 'span' }, ['v grafu ',
                            bs.em({}, 'G'), ' existuje sled z vrcholu ',
                            bs.em({}, 'v'), ' do vrcholu ', bs.em({}, 'w'),
                        ]), { color: colors.greenHighlight }),
                            '.'],
                    ),
                    a.addHint(
                        'whiteboard2',
                        { x: 530, y: 140 },
                        ['Výrok ', bs.em({}, 'A')],
                        undefined,
                        colors.redHighlight,
                        1500
                    ),
                    a.addHint(
                        'whiteboard3',
                        { x: 530, y: 255 },
                        ['Výrok ', bs.em({}, 'B')],
                        undefined,
                        colors.greenHighlight,
                        3000
                    ),
                    a.addWhiteboard(
                        'whiteboard4',
                        { x: 210, y: 350 },
                        [bs.em({}, 'A')],
                        colors.redHighlight,
                        undefined,
                        40,
                        1500,
                        35
                    ),
                    a.addWhiteboard(
                        'whiteboard4.2',
                        { x: 320, y: 350 },
                        [bs.em({}, 'B')],
                        colors.greenHighlight,
                        undefined,
                        40,
                        3000,
                        35
                    ),
                    a.addWhiteboard(
                        'whiteboard4.3',
                        { x: 260, y: 350 },
                        ['\u21D4'],
                        colors.defaultBlack,
                        undefined,
                        40,
                        4000,
                        35
                    )
                ],
                sentence: {
                    text: [
                        bs.strong({}, 'Výrok'),
                        ' je tvrzení, o kterém můžeme prohlásit, jestli je pravdivé nebo nepravdivé',
                        bs.e({ tag: 'br' }),
                        bs.strong({}, 'Složený výrok'),
                        ' vytvoříme složením výroků pomocí logických spojek (konjunkce, disjunkce, implikace, ekvivalence)',
                        bs.e({ tag: 'br' }),
                    ]
                },
                time: 6375
            },
            {
                actions: [
                    a.removeWhiteboard('whiteboard1'),
                    a.removeWhiteboard('whiteboard1.2'),
                    a.removeWhiteboard('whiteboard1.3'),
                    a.removeWhiteboard('whiteboard1.4'),
                    a.removeHint('whiteboard2'),
                    a.removeHint('whiteboard3'),
                    a.removeWhiteboard('whiteboard4'),
                    a.removeWhiteboard('whiteboard4.2'),
                    a.removeWhiteboard('whiteboard4.3'),
                    a.addWhiteboard(
                        'whiteboard5',
                        { x: 240, y: 30 },
                        [bs.em({}, 'A '), '\u21D4', bs.em({}, ' B')],
                        colors.orangeHighlight,
                        undefined,
                        40,
                        0,
                        30
                    ),
                    a.addWhiteboard(
                        'whiteboard6',
                        { x: 200, y: 120 },
                        ['1. implikace: ', bs.em({}, 'A '), '\u21D2', bs.em({}, ' B')],
                        colors.redHighlight,
                        undefined,
                        40,
                        1500
                    ),
                    a.addWhiteboard(
                        'whiteboard6.2',
                        { x: 10, y: 170 },
                        ['Jestliže existuje cesta z vrcholu ',
                            bs.em({}, 'v'), ' do vrcholu ',
                            bs.em({}, 'w'), ', pak v ',
                            bs.em({}, 'G'), ' existuje sled z vrcholu ',
                            bs.em({}, 'v'), ' do vrcholu ',
                            bs.em({}, 'w'), '.'],
                        colors.defaultBlack,
                        undefined,
                        40,
                        1500
                    ),
                    a.addWhiteboard(
                        'whiteboard7',
                        { x: 200, y: 280 },
                        ['2. implikace: ', bs.em({}, 'B '), '\u21D2', bs.em({}, ' A')],
                        colors.greenHighlight,
                        undefined,
                        40,
                        3000
                    ),
                    a.addWhiteboard(
                        'whiteboard7.2',
                        { x: 10, y: 330 },
                        ['Jestliže existuje sled z vrcholu ',
                            bs.em({}, 'v'), ' do vrcholu ',
                            bs.em({}, 'w'), ', pak v ',
                            bs.em({}, 'G'), ' existuje cesta z vrcholu ',
                            bs.em({}, 'v'), ' do vrcholu ',
                            bs.em({}, 'w'), '.'],
                        colors.defaultBlack,
                        undefined,
                        40,
                        3000
                    ),
                ],
                sentence: {
                    text: [
                        bs.strong({}, ['Implikace ',
                            bs.em({}, 'p '), '\u21D2', bs.em({}, ' q')]), ': jestliže platí výrok ',
                        bs.em({}, 'p'), ', pak platí výrok ',
                        bs.em({}, 'q'),
                        bs.e({ tag: 'br' }),
                        bs.strong({}, ['Ekvivalence ',
                            bs.em({}, 'p '), '\u21D4', bs.em({}, ' q')]), ': výrok ',
                        bs.em({}, 'p'), ' platí právě tehdy, když platí výrok ',
                        bs.em({}, 'q'),
                        bs.e({ tag: 'br' }),
                        'Ekvivalenci rozdělíme na dvě implikace, které dokážeme zvlášť. '
                    ]
                },
                time: 5376
            },
            {
                actions: [
                    a.removeWhiteboard('whiteboard5'),
                    a.removeWhiteboard('whiteboard6'),
                    a.removeWhiteboard('whiteboard6.2'),
                    a.removeWhiteboard('whiteboard7.2'),
                    a.removeWhiteboard('whiteboard7'),
                    a.addCloud(),
                    a.addVertex('v', { x: 200, y: 390 }, 'v'),
                    a.addVertex('w', { x: 580, y: 260 }, 'w'),
                    a.addVertex('e', { x: 560, y: 130 }, 'e'),
                    a.addVertex('f', { x: 480, y: 260 }, 'f'),
                    a.addVertex('g', { x: 160, y: 107 }, 'g'),
                    a.addVertex('b', { x: 290, y: 120 }, 'b'),
                    a.addVertex('c', { x: 470, y: 170 }, 'c'),
                    a.addVertex('d', { x: 360, y: 320 }, 'd'),
                    a.addVertex('a', { x: 190, y: 220 }, 'a'),

                    a.addEdge('a-b', 'a', 'b'),
                    a.addEdge('d-f', 'd', 'f'),
                    a.addEdge('b-g', 'b', 'g'),
                    a.addEdge('b-c', 'b', 'c'),
                    a.addEdge('c-w', 'c', 'w'),
                    a.addEdge('b-d', 'b', 'd'),
                    a.addEdge('c-d', 'c', 'd'),
                    a.addEdge('c-e', 'c', 'e'),
                    a.addEdge('a-v', 'a', 'v'),
                    a.highlightEdge('a-b', a.HighlightType.Full, undefined, undefined, undefined, undefined, 2000, 'a-b-red'),
                    a.highlightEdge('a-v', a.HighlightType.Full, undefined, undefined, undefined, undefined, 1000, 'a-v-red'),
                    a.highlightEdge('b-c', a.HighlightType.Full, undefined, undefined, undefined, undefined, 3000, 'b-c-red'),
                    a.highlightEdge('c-w', a.HighlightType.Full, undefined, undefined, undefined, undefined, 4000, 'c-w-red'),
                    a.highlightVertex('v'),
                    a.highlightVertex('w'),

                    a.editVertex('v', undefined, undefined, undefined, undefined, colors.redHighlightLight, undefined),
                    a.editVertex('w', undefined, undefined, undefined, undefined, colors.redHighlightLight, undefined, 5000),
                    a.editVertex('b', undefined, undefined, undefined, undefined, colors.redHighlightLight, undefined, 3000),
                    a.editVertex('c', undefined, undefined, undefined, undefined, colors.redHighlightLight, undefined, 4000),
                    a.editVertex('a', undefined, undefined, undefined, undefined, colors.redHighlightLight, undefined, 2000),

                    a.addHint(
                        'cesta-1',
                        { x: 230, y: 340 },
                        ['cesta ', bs.em({}, 'P '), '=', bs.em({}, ' (v, a, b, c, w)')],
                        undefined, undefined, 0
                    )
                ],
                sentence: {
                    text: [bs.strong({}, 'Důkaz přímo'), ': Přepokládáme, že ',
                    bs.em({}, 'A'), ' platí. Řetězcem implikací dojdeme k závěru ',
                    bs.em({}, 'B'), ': ',
                    bs.e({ tag: 'br' }),
                    bs.em({}, ['A ']), '\u21D2', bs.em({}, [' B',
                        bs.sub({}, '1')]), ' \u21D2', bs.em({}, [' B',
                        bs.sub({}, '2')]), ' \u21D2 ... \u21D2', bs.em({}, [' B',
                        bs.sub({}, 'n')]), ' \u21D2', bs.em({}, [' B']),
                    bs.e({ tag: 'br' }),
                        'Existuje cesta z vrcholu ',
                    bs.em({}, 'v'),
                        ' do vrcholu ',
                    bs.em({}, 'w'),
                        ' \u21D2 ... \u21D2 Existuje sled z vrcholu ',
                    bs.em({}, 'v'),
                        ' do ',
                    bs.em({}, 'w'),
                        '.'
                    ]
                },
                time: 7375
            },
            {
                actions: [
                    a.removeHint('cesta-1'),
                    a.addHint(
                        'cesta-2',
                        { x: 230, y: 340 },
                        ['cesta ',
                            bs.em({}, 'P '), '=', bs.em({}, ' (v, a, b, c, w)'),
                            ' = sled'],
                        undefined, undefined, 0
                    )
                ],
                sentence: {
                    text: [
                        'Definice cesty: ',
                        bs.e({ tag: 'br' }),
                        bs.strong({}, 'Cesta'), ' je ', bs.strong({}, 'sled'), ' s navzájem různými vrcholy, tj. pro ',
                        bs.em({}, 'i '), '\u2260', bs.em({}, ' j'), ' platí ',
                        bs.em({}, [
                            'v', bs.sub({}, 'i'), ' \u2260 v', bs.sub({}, 'j')
                        ]),
                        bs.e({ tag: 'br' }),
                        'Cesta je dle definice vždy sledem, přímo jsme dokázali 1. implikaci'
                    ]
                },
                time: 2374
            },
            {
                actions: [
                    a.removeHint('cesta-2'),
                    a.unHighlightVertex('v'),
                    a.unHighlightVertex('w'),

                    a.editVertex('v', undefined, undefined, undefined, undefined, colors.defaultVertex),
                    a.editVertex('w', undefined, undefined, undefined, undefined, colors.defaultVertex),
                    a.editVertex('a', undefined, undefined, undefined, undefined, colors.defaultVertex),
                    a.editVertex('b', undefined, undefined, undefined, undefined, colors.defaultVertex),
                    a.editVertex('c', undefined, undefined, undefined, undefined, colors.defaultVertex),
                    a.editVertex('d', undefined, undefined, undefined, undefined, colors.defaultVertex),

                    a.unHighlightEdge('a-b-red', a.HighlightType.Full),
                    a.unHighlightEdge('a-v-red', a.HighlightType.Full),
                    a.unHighlightEdge('b-c-red', a.HighlightType.Full),
                    a.unHighlightEdge('c-w-red', a.HighlightType.Full),

                ],
                sentence: {
                    text: [
                        bs.strong({}, 'Sled'), ' je posloupnost vrcholů a hran, začíná a končí ve vrcholu',
                        bs.e({ tag: 'br' }),
                        '\u2022 Hrany a vrcholy se ',
                        bs.strong({}, 'mohou'),
                        ' opakovat'
                    ]
                },
                time: 500
            },
            {
                actions: [
                    a.editVertex('v', undefined, undefined, colors.greenHighlight, 7, colors.greenHighlightLight),
                    a.editVertex('w', undefined, undefined, colors.greenHighlight, 7, colors.greenHighlightLight, undefined, 10000),
                    a.editVertex('e', undefined, undefined, undefined, undefined, colors.greenHighlightLight, undefined, 7000),
                    a.editVertex('a', undefined, undefined, undefined, undefined, colors.greenHighlightLight, undefined, 1000),
                    a.editVertex('b', undefined, undefined, undefined, undefined, colors.greenHighlightLight, undefined, 2000),
                    a.editVertex('c', undefined, undefined, undefined, undefined, colors.greenHighlightLight, undefined, 3000),
                    a.editVertex('d', undefined, undefined, undefined, undefined, colors.greenHighlightLight, undefined, 4000),

                    a.removeEdge('b-c'),

                    a.addEdge('b-c', 'b', 'c', undefined, undefined, undefined, undefined, 10, 5),
                    a.addEdge('b-c1', 'b', 'c', undefined, 7, colors.greenHighlight, undefined, 50, 5, 2000),
                    a.addEdge('b-c2', 'b', 'c', undefined, 7, colors.greenHighlight, undefined, 50, -5, 5000),

                    a.removeEdge('c-e'),

                    a.addEdge('c-e', 'c', 'e', undefined, undefined, undefined, undefined, 10, 5),
                    a.addEdge('c-e1', 'c', 'e', undefined, 7, colors.greenHighlight, undefined, 50, 5, 6000),
                    a.addEdge('c-e2', 'c', 'e', undefined, 7, colors.greenHighlight, undefined, 50, -5, 8000),

                    a.highlightEdge('b-d', a.HighlightType.Full, undefined, colors.greenHighlight, undefined, undefined, 4000, 'b-d-green'),
                    a.highlightEdge('c-d', a.HighlightType.Full, undefined, colors.greenHighlight, undefined, undefined, 3000, 'c-d-green'),
                    a.highlightEdge('a-b', a.HighlightType.Full, undefined, colors.greenHighlight, undefined, undefined, 1000, 'a-b-green'),
                    a.highlightEdge('a-v', a.HighlightType.Full, undefined, colors.greenHighlight, undefined, undefined, 0, 'a-v-green'),
                    a.highlightEdge('c-w', a.HighlightType.Full, undefined, colors.greenHighlight, undefined, undefined, 9000, 'c-w-green'),

                    a.addHint(
                        'sled-1', { x: 370, y: 320 }, ['sled ', bs.em({}, 'S '), '=', bs.em({}, ' (v, a, b, c, d, b, c, e, c, w)')],
                        undefined,
                        colors.greenHighlight,
                        0
                    ),
                ],
                sentence: {
                    text: [
                        bs.strong({}, 'Sled'), ' je posloupnost vrcholů a hran, začíná a končí ve vrcholu',
                        bs.e({ tag: 'br' }),
                        '\u2022 Hrany a vrcholy se ',
                        bs.strong({}, 'mohou'),
                        ' opakovat'
                    ]
                },
                time: 10375
            },
            {
                actions: [
                    a.removeHint('sled-1'),
                    a.unHighlightEdge('b-d-green', a.HighlightType.Full),
                    a.unHighlightEdge('c-d-green', a.HighlightType.Full),
                    a.removeEdge('b-c1'),
                    a.removeEdge('b-c2'),
                    a.removeEdge('b-c'),
                    a.removeEdge('c-e1'),
                    a.removeEdge('c-e2'),
                    a.removeEdge('c-e'),
                    a.addEdge('b-c', 'b', 'c'),
                    a.addEdge('c-e', 'c', 'e'),
                    a.editVertex('d', undefined, undefined, undefined, undefined, colors.defaultVertex),
                    a.editVertex('e', undefined, undefined, undefined, undefined, colors.defaultVertex),
                    a.highlightEdge('b-c', a.HighlightType.Full, undefined, colors.greenHighlight),
                    a.addHint(
                        'sled-2', { x: 370, y: 320 }, ['podsled ',
                            bs.em({}, ['S', bs.sub({}, 'min ')]), '=', bs.em({}, [' (v, a, b, c, w)']), ' = cesta?'],
                        undefined,
                        colors.greenHighlight,
                        0
                    ),
                ],
                sentence: {
                    text: [
                        'V minimálním podsledu se neopakují vrcholy a hrany - odpovídá cestě.',
                        bs.e({ tag: 'br' }),
                        bs.strong({}, 'Důkaz sporem: '),
                        bs.e({ tag: 'br' }),
                        'Vytvoříme negaci věty, odvozujeme logické důsledky až dojdeme k výroku ',
                        bs.em({}, ['S']), ', který je nepravdivý. Negace věty tedy neplatí, platí původní věta. ',
                    ]
                },
                time: 2375
            },
            {
                actions: [
                    a.removeHint('sled-2'),
                    a.unHighlightEdge('b-c', a.HighlightType.Full),
                    a.unHighlightEdge('a-b-green', a.HighlightType.Full),
                    a.unHighlightEdge('a-v-green', a.HighlightType.Full),
                    a.unHighlightEdge('c-w-green', a.HighlightType.Full),

                    a.editVertex('v', undefined, undefined, undefined, undefined, colors.defaultVertex),
                    a.editVertex('w', undefined, undefined, undefined, undefined, colors.defaultVertex),
                    a.editVertex('a', undefined, undefined, undefined, undefined, colors.defaultVertex),
                    a.editVertex('b', undefined, undefined, undefined, undefined, colors.defaultVertex),
                    a.editVertex('c', undefined, undefined, undefined, undefined, colors.defaultVertex),
                    a.editVertex('d', undefined, undefined, undefined, undefined, colors.defaultVertex),

                    a.addHint(
                        'sled-3', { x: 320, y: 370 }, [
                            'Předpokládáme, že v grafu ',
                            bs.e({ tag: 'br' }),
                            'existuje minimální podsled  ',
                            bs.em({}, ['S',
                                bs.sub({}, 'min, ')]),
                            bs.e({ tag: 'br' }),
                            'který není cesta.',
                        ],
                        undefined,
                        colors.greenHighlight,
                        0
                    ),
                ],
                sentence: {
                    text: [
                        bs.strong({}, 'Důkaz sporem: '),
                        bs.e({ tag: 'br' }),
                        'Věta: ',
                        bs.strong({}, 'Jestliže'),
                        ' existuje sled ',
                        bs.em({}, ['S',
                            bs.sub({}, 'min')]),
                        ' minimální délky z ',
                        bs.em({}, ['v']), ' do ',
                        bs.em({}, ['w']), ', ',
                        bs.strong({}, 'pak'),
                        bs.em({}, [' S',
                            bs.sub({}, 'min')]),
                        ' je cesta z v do w.',
                        bs.e({ tag: 'br' }),
                        'Negace: Existuje sled ',
                        bs.em({}, ['S',
                            bs.sub({}, 'min')]),
                        ' minimální délky z v do w ',
                        bs.strong({}, 'a zároveň'),
                        bs.em({}, [' S',
                            bs.sub({}, 'min')]),
                        bs.strong({}, ' není'),
                        ' cesta z ',
                        bs.em({}, ['v']), ' do ',
                        bs.em({}, ['w']), '.',
                        bs.e({ tag: 'br' }),
                        'Věta: ',
                        bs.em({}, 'A '), '\u21D2', bs.em({}, ' B'), ', negace: ',
                        bs.em({}, 'A '), '\u2227', bs.em({}, ' B'), '\u2032'
                    ]
                },
                time: 500
            },
            {
                actions: [
                    a.removeHint('sled-3'),

                    a.removeEdge('b-c'),
                    a.addEdge('b-c', 'b', 'c', undefined, undefined, undefined, undefined, 10, 5),
                    a.addEdge('b-c1', 'b', 'c', undefined, 7, colors.greenHighlight, undefined, 50, 5, 2000),
                    a.addEdge('b-c2', 'b', 'c', undefined, 7, colors.greenHighlight, undefined, 50, -5, 5000),

                    a.editVertex('v', undefined, undefined, undefined, undefined, colors.greenHighlightLight),
                    a.editVertex('w', undefined, undefined, undefined, undefined, colors.greenHighlightLight, undefined, 7000),
                    a.editVertex('a', undefined, undefined, undefined, undefined, colors.greenHighlightLight, undefined, 1000),
                    a.editVertex('b', undefined, undefined, undefined, undefined, colors.greenHighlightLight, undefined, 2000),
                    a.editVertex('c', undefined, undefined, undefined, undefined, colors.greenHighlightLight, undefined, 3000),
                    a.editVertex('d', undefined, undefined, undefined, undefined, colors.greenHighlightLight, undefined, 4000),

                    a.highlightEdge('b-d', a.HighlightType.Full, undefined,
                        colors.greenHighlight, undefined, undefined, 4000, 'b-d-green2'),
                    a.highlightEdge('c-d', a.HighlightType.Full, undefined,
                        colors.greenHighlight, undefined, undefined, 3000, 'c-d-green2'),
                    a.highlightEdge('a-b', a.HighlightType.Full, undefined,
                        colors.greenHighlight, undefined, undefined, 1000, 'a-b-green2'),
                    a.highlightEdge('a-v', a.HighlightType.Full, undefined,
                        colors.greenHighlight, undefined, undefined, 0, 'a-v-green2'),
                    a.highlightEdge('c-w', a.HighlightType.Full, undefined,
                        colors.greenHighlight, undefined, undefined, 6000, 'c-w-green2'),

                    a.addHint(
                        'sled-35', { x: 320, y: 370 }, [
                            'Pro pochopení důkazu uvažujme,',
                            bs.e({ tag: 'br' }),
                            'že tento ',
                            bs.em({}, ['S',
                                bs.sub({}, 'min')]),
                            ' je minimální podsled',
                            bs.e({ tag: 'br' }),
                            'a zároveň není cesta.',
                            bs.e({ tag: 'br' }),
                            'Podsled ',
                            bs.em({}, ['S', bs.sub({}, 'min ')]), '=', bs.em({}, [' (v, a, b, c, d, b, c, w)']),
                        ],
                        undefined,
                        colors.greenHighlight,
                        0
                    ),
                ],
                sentence: {
                    text: [
                        bs.strong({}, 'Důkaz sporem: '),
                        bs.e({ tag: 'br' }),
                        'Věta: ',
                        bs.strong({}, 'Jestliže'),
                        ' existuje sled ',
                        bs.em({}, ['S',
                            bs.sub({}, 'min')]),
                        ' minimální délky z ',
                        bs.em({}, ['v']), ' do ',
                        bs.em({}, ['w']), ', ',
                        bs.strong({}, 'pak'),
                        bs.em({}, [' S',
                            bs.sub({}, 'min')]),
                        ' je cesta z v do w.',
                        bs.e({ tag: 'br' }),
                        'Negace: Existuje sled ',
                        bs.em({}, ['S',
                            bs.sub({}, 'min')]),
                        ' minimální délky z v do w ',
                        bs.strong({}, 'a zároveň'),
                        bs.em({}, [' S',
                            bs.sub({}, 'min')]),
                        bs.strong({}, ' není'),
                        ' cesta z ',
                        bs.em({}, ['v']), ' do ',
                        bs.em({}, ['w']), '.',
                        bs.e({ tag: 'br' }),
                        'Věta: ',
                        bs.em({}, 'A '), '\u21D2', bs.em({}, ' B'), ', negace: ',
                        bs.em({}, 'A '), '\u2227', bs.em({}, ' B'), '\u2032'
                    ]
                },
                time: 8375
            },
            {
                actions: [
                    a.removeHint('sled-35'),
                    a.highlightVertex('b', undefined, colors.redHighlight),
                    a.highlightVertex('c', undefined, colors.redHighlight),
                    a.addHint(
                        'sled-4', { x: 320, y: 370 }, [
                            'Vrcholy b, c se v podsledu ',
                            bs.e({ tag: 'br' }),
                            'vyskytují dvakrát.',
                            bs.e({ tag: 'br' }),
                            'Podsled ',
                            bs.em({}, ['S', bs.sub({}, 'min ')]), '=', bs.em({}, [' (v, a, b, c, d, b, c, w)']),
                        ],
                        undefined,
                        colors.greenHighlight,
                        0
                    ),
                ],
                sentence: {
                    text: [
                        bs.strong({}, 'Cesta'), ' je sled s navzájem různými vrcholy, tj. pro ',
                        bs.em({}, 'i '), '\u2260', bs.em({}, ' j'), ' platí ',
                        bs.em({}, [
                            'v', bs.sub({}, 'i'), ' \u2260 v', bs.sub({}, 'j')
                        ]),
                        bs.e({ tag: 'br' }),
                        '\u2022 Hrany a vrcholy se ', bs.strong({}, 'nesmí'), ' opakovat']
                },
                time: 2374
            },
            {
                actions: [
                    a.removeHint('sled-4'),
                    a.unHighlightEdge('b-d-green2', a.HighlightType.Full),
                    a.unHighlightEdge('c-d-green2', a.HighlightType.Full),
                    a.removeEdge('b-c1'),
                    a.removeEdge('b-c2'),
                    a.removeEdge('b-c'),
                    a.addEdge('b-c', 'b', 'c'),
                    a.highlightEdge('b-c', a.HighlightType.Full, undefined, colors.greenHighlight),
                    a.unHighlightVertex('b'),
                    a.unHighlightVertex('c'),
                    a.editVertex('b', undefined, undefined, undefined, undefined, colors.greenHighlightLight),
                    a.editVertex('c', undefined, undefined, undefined, undefined, colors.greenHighlightLight),
                    a.editVertex('d', undefined, undefined, undefined, undefined, colors.defaultVertex),
                    a.addHint(
                        'sled-5', { x: 320, y: 370 }, [
                            'Odebrali jsme posloupnost b, c, d.',
                            bs.e({ tag: 'br' }),
                            'Původní podsled ',
                            bs.em({}, ['S', bs.sub({}, 'min ')]), '=', bs.em({}, [' (v, a, b, c, d, b, c, w)']),
                            bs.e({ tag: 'br' }),
                            'Podsled ', bs.em({}, ['S']), ' kratší než ',
                            bs.em({}, ['S', bs.sub({}, 'min ')]), '=', bs.em({}, [' (v, a, b, c, w)']),
                        ],
                        undefined,
                        colors.greenHighlight, 0
                    ),
                ],
                sentence: {
                    text: [
                        'Vyvrátili jsme předpoklad, negace je tedy nepravdivá a platí původní věta.',
                        bs.e({ tag: 'br' }),
                        bs.s({}, [
                            'Negace: Existuje sled ',
                            bs.em({}, ['S',
                                bs.sub({}, 'min')]),
                            ' minimální délky z v do w ',
                            'a zároveň',
                            bs.em({}, [' S',
                                bs.sub({}, 'min')]),
                            ' není',
                            ' cesta z ',
                            bs.em({}, ['v']), ' do ',
                            bs.em({}, ['w']), '.',
                        ]),
                        bs.e({ tag: 'br' }),
                        'Původní věta: ',
                        'Jestliže',
                        ' existuje sled ',
                        bs.em({}, ['S',
                            bs.sub({}, 'min')]),
                        ' minimální délky z ',
                        bs.em({}, ['v']), ' do ',
                        bs.em({}, ['w']), ', ',
                        'pak',
                        bs.em({}, [' S',
                            bs.sub({}, 'min')]),
                        ' je cesta z v do w.',
                        bs.e({ tag: 'br' }),
                    ]
                },
                time: 2375
            }
        ]
    },
];