import * as b from 'bobril';
import * as bs from 'bobrilstrap';
import * as a from '../../viewer/actions';
import * as colors from '../../common/colors';

export const examples = () => [
    {
        name: 'veta5', definitions: [
            { // 0
                nesting: 0,
                color: colors.orangeHighlight,
                text: [
                    'Věta: Pro každý graf ',
                    bs.em({}, 'T '), '=', bs.em({}, ' (V, E)'), ' platí: ',
                    'Graf ',
                    bs.em({}, 'T'), ' je strom právě tehdy, když neobsahuje kružnici a každý graf vzniklý z ',
                    bs.em({}, 'T'), ' přidáním hrany, která spojuje libovolné dva nesousední vrcholy grafu ',
                    bs.em({}, 'T'), ', již kružnici obsahuje. ',
                ]
            },
            { // 1
                nesting: 0,
                color: colors.orangeHighlight,
                text: [
                    'Rozdělení věty na dva výroky ',
                    bs.em({}, 'A'),
                    ' a ',
                    bs.em({}, 'B'),
                    ' spojené pomocí ekvivalence. '
                ]
            },
            { // 2
                nesting: 0,
                color: colors.orangeHighlight,
                text: 'Ekvivalenci dokážeme rozdělením na dvě implikace. '
            },
            { // 3
                nesting: 0,
                color: colors.blueHighlight,
                text: [
                    '1. implikace: Jestliže graf ',
                    bs.em({}, 'T'), ' je strom, pak neobsahuje kružnici a každý graf vzniklý z ',
                    bs.em({}, 'T'), ' přidáním hrany, která spojuje libovolné dva nesousední vrcholy grafu ',
                    bs.em({}, 'T'), ', již kružnici obsahuje. ',
                ]
            },
            { // 4
                nesting: 1,
                color: colors.blueHighlightLight,
                text: [
                    'Dokážeme přímo. Již podle definice stromu víme, že neobsahuje kružnici. ',
                ]
            },
            { // 5
                nesting: 1,
                color: colors.blueHighlightLight,
                text: [
                    'Podle definice stromu také víme, že je souvislý, tedy mezi libovolnými dvěma vrcholy existuje cesta. ',
                    'Mezi nesousedními vrcholy ',
                    bs.em({}, 'x'), ' a ',
                    bs.em({}, 'y'), ' existuje cesta ',
                    bs.em({}, 'P.'),
                ]
            },
            { // 6
                nesting: 1,
                color: colors.blueHighlightLight,
                text: [
                    'K této cestě přidáme hranu ',
                    bs.em({}, '{x, y}'), '.'
                ]
            },
            { // 7
                nesting: 1,
                color: colors.blueHighlightLight,
                text: [
                    'Tím vznikne kružnice ',
                    bs.em({}, [
                        '(x, y, P)'
                    ]), '. Dokázali jsme první implikaci. ',
                ]
            },
            { // 8
                nesting: 0,
                color: colors.pinkHighlight,
                text: [
                    '2. implikace: Jestliže graf ',
                    bs.em({}, 'T'), ' neobsahuje kružnici a každý graf vzniklý z ',
                    bs.em({}, 'T'), ' přidáním hrany, která spojuje libovolné dva nesousední vrcholy grafu ',
                    bs.em({}, 'T'), ', již kružnici obsahuje, pak graf ',
                    bs.em({}, 'T'), ' je strom. ',
                ]
            },
            { // 9
                nesting: 1,
                color: colors.pinkHighlightLight,
                text: [
                    'Dokážeme sporem: Existuje graf ',
                    bs.em({}, 'T'), ', který neobsahuje kružnici a každý graf vzniklý z ',
                    bs.em({}, 'T'), ' přidáním hrany, která spojuje libovolné dva nesousední vrcholy grafu ',
                    bs.em({}, 'T'), ', již kružnici obsahuje a zároveň graf ',
                    bs.em({}, 'T'), ' není strom. Graf není stromem když obsahuje kružnici nebo je nesouvislý.',
                ]
            },
            { // 10
                nesting: 1,
                color: colors.purpleHighlight,
                text: [
                    'a. Graf obsahuje kružnici. Došli jsme ke sporu s předpokladem, že graf neobsahuje kružnici. ',
                ]
            },
            { // 11
                nesting: 1,
                color: colors.redHighlight,
                text: [
                    'b. Graf je nesouvislý. To znamená, že v něm existují alespoň dvě komponenty ',
                    bs.em({}, ['K', bs.sub({}, '1')]),
                    ' a ',
                    bs.em({}, ['K', bs.sub({}, '2')]),
                    '. '
                ]
            },
            { // 12
                nesting: 2,
                color: colors.redHighlightLight,
                text: [
                    'Přidáme hranu ',
                    bs.em({}, '{x, y}'),
                    ', kde ',
                    bs.em({}, 'x'),
                    ' leží na ',
                    bs.em({}, ['K', bs.sub({}, '1')]),
                    ' a ',
                    bs.em({}, 'y'),
                    ' leží na ',
                    bs.em({}, ['K', bs.sub({}, '2')]),
                    '.',
                ]
            },
            { // 13
                nesting: 2,
                color: colors.redHighlightLight,
                text: [
                    'Tím ale v grafu nevznikne kružnice, protože mezi ',
                    bs.em({}, ['{x, y}']),
                    ' existuje jen jedna cesta. Hrana ',
                    bs.em({}, ['{x, y}']),
                    ' je most. Došli jsme ke sporu s přepokladem, že přidáním hrany mezi nesousedními vrcholy kružnice vznikne. Dokázali jsme druhou implikaci. ',
                ]
            }
        ],
        steps: [
            { // 0
                actions: [
                    a.addWhiteboard(
                        'whiteboard1',
                        { x: 0, y: 50 },
                        ['Pro každý graf ', bs.em({}, 'T'), ' = ', bs.em({}, '(V, E)'), ' platí:'],
                        undefined,
                        undefined,
                        40,
                        0
                    ),
                    a.addWhiteboard(
                        'whiteboard1.2',
                        { x: 0, y: 110 },
                        ['Graf ', bs.em({}, 'T'), ' je strom '],
                        undefined,
                        undefined,
                        40,
                        1500
                    ),
                    a.addWhiteboard(
                        'whiteboard1.3',
                        { x: 0, y: 170 },
                        [bs.strong({}, [' právě tehdy, když '])],
                        undefined,
                        undefined,
                        40,
                        2250
                    ),
                    a.addWhiteboard(
                        'whiteboard1.4',
                        { x: 0, y: 230 },
                        [
                            'neobsahuje kružnici a každý graf vzniklý z ',
                            bs.em({}, 'T'),
                            bs.e({ tag: 'br' }),
                            'přidáním hrany, která spojuje libovolné dva',
                            bs.e({ tag: 'br' }),
                            'nesousední vrcholy grafu ',
                            bs.em({}, 'T'), ', již kružnici obsahuje.',
                        ],
                        undefined,
                        undefined,
                        40,
                        3000
                    ),
                ],
                sentence: {
                    text: [
                        bs.strong({}, 'Graf'), ' je definován množinou vrcholů ',
                        bs.em({}, ['V']), ' a hran ',
                        bs.em({}, ['E']), '. ',
                        bs.e({ tag: 'br' }),
                        bs.strong({}, 'Strom'), ' je souvislý graf, který neobsahuje kružnici. Značíme písmenem ',
                        bs.em({}, 'T'), ' (ze slova tree).',
                        bs.e({ tag: 'br' }),
                        bs.strong({}, 'Kružnice (cyklus)'), ' v grafu ',
                        bs.em({}, 'G'),
                        ' je posloupnost',
                        bs.em({}, [
                            '(v',
                            bs.sub({}, '0'), ', e',
                            bs.sub({}, '1'), ', v',
                            bs.sub({}, '1'), ', ..., e',
                            bs.sub({}, 'k'), ', v',
                            bs.sub({}, '0'), ')'
                        ]),
                        ' kde ',
                        bs.em({}, ['e', bs.sub({}, 'i')]), ' = ', bs.em({}, ['{v', bs.sub({}, 'i-1'), ', v', bs.sub({}, 'i'), '}, i']),
                        ' = ', bs.em({}, ['1,..., k-1; ']),
                        bs.em({}, ['e', bs.sub({}, 'k')]), ' = ', bs.em({}, ['{v', bs.sub({}, 'k-1'), ', v', bs.sub({}, '0'), '}'
                        ]),
                    ]
                },
                time: 5100
            },
            { // 1
                actions: [
                    a.editWhiteboard(
                        'whiteboard1.2',
                        undefined,
                        [b.style(bs.element({ tag: 'span' }, [
                            'Graf ', bs.em({}, 'T'), ' je strom ',
                        ]), { color: colors.redHighlight })],
                    ),
                    a.editWhiteboard(
                        'whiteboard1.4',
                        undefined,
                        [b.style(bs.element({ tag: 'span' }, [
                            'neobsahuje kružnici a každý graf vzniklý z ',
                            bs.em({}, 'T'),
                            bs.e({ tag: 'br' }),
                            'přidáním hrany, která spojuje libovolné dva',
                            bs.e({ tag: 'br' }),
                            'nesousední vrcholy grafu ',
                            bs.em({}, 'T'), ', již kružnici obsahuje.',
                        ]), { color: colors.greenHighlight })],
                    ),
                    a.addHint(
                        'whiteboard2',
                        { x: 530, y: 140 },
                        ['Výrok ', bs.em({}, 'A')],
                        undefined,
                        colors.redHighlight,
                        1500
                    ),
                    a.addHint(
                        'whiteboard3',
                        { x: 530, y: 255 },
                        ['Výrok ', bs.em({}, 'B')],
                        undefined,
                        colors.greenHighlight,
                        3000
                    ),
                    a.addWhiteboard(
                        'whiteboard4',
                        { x: 210, y: 350 },
                        [bs.em({}, 'A')],
                        colors.redHighlight,
                        undefined,
                        40,
                        1500,
                        35
                    ),
                    a.addWhiteboard(
                        'whiteboard4.2',
                        { x: 320, y: 350 },
                        [bs.em({}, 'B')],
                        colors.greenHighlight,
                        undefined,
                        40,
                        3000,
                        35
                    ),
                    a.addWhiteboard(
                        'whiteboard4.3',
                        { x: 260, y: 350 },
                        ['\u21D4'],
                        colors.defaultBlack,
                        undefined,
                        40,
                        4000,
                        35
                    )
                ],
                sentence: {
                    text: [
                        bs.strong({}, 'Výrok')
                        , ' je tvrzení, o kterém můžeme prohlásit, jestli je pravdivé nebo nepravdivé',
                        bs.e({ tag: 'br' }),
                        bs.strong({}, 'Složený výrok')
                        , ' vytvoříme složením výroků pomocí logických spojek (konjunkce, disjunkce, implikace, ekvivalence)',
                        bs.e({ tag: 'br' }),
                    ]
                },
                time: 6100
            },
            { // 2
                actions: [
                    a.removeWhiteboard('whiteboard1'),
                    a.removeWhiteboard('whiteboard1.2'),
                    a.removeWhiteboard('whiteboard1.3'),
                    a.removeWhiteboard('whiteboard1.4'),
                    a.removeHint('whiteboard2'),
                    a.removeHint('whiteboard3'),
                    a.removeWhiteboard('whiteboard4'),
                    a.removeWhiteboard('whiteboard4.2'),
                    a.removeWhiteboard('whiteboard4.3'),
                    a.addWhiteboard(
                        'whiteboard5',
                        { x: 240, y: 30 },
                        [bs.em({}, 'A'),
                            ' \u21D4 ',
                        bs.em({}, 'B')],
                        colors.orangeHighlight,
                        undefined,
                        40,
                        0,
                        30
                    ),
                    a.addWhiteboard(
                        'whiteboard6',
                        { x: 200, y: 120 },
                        ['1. implikace: ',
                            bs.em({}, 'A'),
                            ' \u21D2 ',
                            bs.em({}, 'B')],
                        colors.redHighlight,
                        undefined,
                        40,
                        1500
                    ),
                    a.addWhiteboard(
                        'whiteboard6.2',
                        { x: 10, y: 170 },
                        [
                            'Jestliže graf ',
                            bs.em({}, 'T'), ' je strom, pak neobsahuje kružnici a každý graf vzniklý z ',
                            bs.em({}, 'T'), ' přidáním hrany, která spojuje libovolné dva nesousední vrcholy grafu ',
                            bs.em({}, 'T'), ', již kružnici obsahuje. ',
                        ],
                        colors.defaultBlack,
                        undefined,
                        40,
                        1500
                    ),
                    a.addWhiteboard(
                        'whiteboard7',
                        { x: 200, y: 280 },
                        ['2. implikace: ', bs.em({}, 'B '), '\u21D2', bs.em({}, ' A')],
                        colors.greenHighlight,
                        undefined,
                        40,
                        3000
                    ),
                    a.addWhiteboard(
                        'whiteboard7.2',
                        { x: 10, y: 330 },
                        [
                            'Jestliže graf ',
                            bs.em({}, 'T'), ' neobsahuje kružnici a každý graf vzniklý z ',
                            bs.em({}, 'T'), ' přidáním hrany, která spojuje libovolné dva nesousední vrcholy grafu ',
                            bs.em({}, 'T'), ', již kružnici obsahuje, pak graf ',
                            bs.em({}, 'T'), ' je strom. ',
                        ],
                        colors.defaultBlack,
                        undefined,
                        40,
                        3000
                    ),
                ],
                sentence: {
                    text: [
                        bs.strong({}, ['Implikace ',
                            bs.em({}, 'p'), ' \u21D2 ', bs.em({}, 'q')]), ': jestliže platí výrok ',
                        bs.em({}, 'p'), ', pak platí výrok ',
                        bs.em({}, 'q'),
                        bs.e({ tag: 'br' }),
                        bs.strong({}, ['Ekvivalence ',
                            bs.em({}, 'p'), ' \u21D4 ', bs.em({}, 'q')]), ': výrok ',
                        bs.em({}, 'p'), ' platí právě tehdy, když platí výrok ',
                        bs.em({}, 'q'),
                        bs.e({ tag: 'br' }),
                        'Ekvivalenci rozdělíme na dvě implikace, které dokážeme zvlášť. '
                    ]
                },
                time: 5376
            },
            { // 3
                actions: [
                    a.removeWhiteboard('whiteboard5'),
                    a.removeWhiteboard('whiteboard6'),
                    a.removeWhiteboard('whiteboard6.2'),
                    a.removeWhiteboard('whiteboard7.2'),
                    a.removeWhiteboard('whiteboard7'),

                    a.addCloud(),

                    a.addVertex('a', { x: 200, y: 300 }, 'a'),
                    a.addVertex('b', { x: 190, y: 220 }, 'b'),
                    a.addVertex('c', { x: 290, y: 320 }, 'c'),
                    a.addVertex('h', { x: 590, y: 270 }, 'h'),
                    a.addVertex('g', { x: 300, y: 150 }, 'g'),
                    a.addVertex('e', { x: 500, y: 300 }, 'e'),
                    a.addVertex('i', { x: 160, y: 107 }, 'i'),
                    a.addVertex('d', { x: 580, y: 170 }, 'd'),
                    a.addVertex('f', { x: 400, y: 200 }, 'f'),

                    a.addEdge('a-b', 'a', 'b'),
                    a.addEdge('d-e', 'd', 'e'),
                    a.addEdge('c-f', 'c', 'f'),
                    a.addEdge('d-g', 'd', 'g'),
                    a.addEdge('b-c', 'b', 'c'),
                    a.addEdge('c-d', 'c', 'd'),
                    a.addEdge('e-h', 'e', 'h'),
                    a.addEdge('b-i', 'b', 'i'),
                ],
                sentence: {
                    text: [
                        bs.strong({}, 'Strom'), ' je souvislý graf, který neobsahuje kružnici. Značíme písmenem ',
                        bs.em({}, 'T'), ' (ze slova tree).',
                        bs.e({ tag: 'br' }),
                        bs.strong({}, 'Kružnice (cyklus)'), ' v grafu ',
                        bs.em({}, 'G'),
                        ' je posloupnost',
                        bs.em({}, [
                            '(v',
                            bs.sub({}, '0'), ', e',
                            bs.sub({}, '1'), ', v',
                            bs.sub({}, '1'), ', ..., e',
                            bs.sub({}, 'k'), ', v',
                            bs.sub({}, '0'), ')'
                        ]),
                        ' kde ',
                        bs.em({}, ['e', bs.sub({}, 'i')]), ' = ', bs.em({}, ['{v', bs.sub({}, 'i-1'), ', v', bs.sub({}, 'i'), '}, i']),
                        ' = ', bs.em({}, ['1,..., k-1; ']),
                        bs.em({}, ['e', bs.sub({}, 'k')]), ' = ', bs.em({}, ['{v', bs.sub({}, 'k-1'), ', v', bs.sub({}, '0'), '}'
                        ])]
                },
                time: 100
            },
            { // 4
                actions: [
                    a.addHint('dukaz-2', { x: 200, y: 20 }, [
                        'Graf neobsahuje kružnici.',
                    ], undefined, colors.blueHighlight, 0),
                ],
                sentence: {
                    text: [
                        bs.strong({}, 'Důkaz přímo:'),
                        bs.e({ tag: 'br' }),
                        'Předpokládáme, že výrok ',
                        bs.em({}, 'A'),
                        ' platí a řetězcem implikací dojdeme k závěru ',
                        bs.em({}, 'B'),
                        ': ',
                        bs.e({ tag: 'br' }),
                        bs.em({}, 'A '), '\u21D2', 
                        bs.em({}, [' B', bs.sub({}, '1')]), ' \u21D2', 
                        bs.em({}, [' B', bs.sub({}, '2')]), ' \u21D2 ... \u21D2', 
                        bs.em({}, [' B', bs.sub({}, 'n')]), ' \u21D2', bs.em({}, ' B'),
                        bs.e({ tag: 'br' }),
                        bs.strong({}, 'Strom'), ' je souvislý graf, který neobsahuje kružnici.',
                    ]
                },
                time: 500
            },
            { // 5
                actions: [
                    a.removeHint('dukaz-2'),
                    a.addHint('dukaz-3', { x: 200, y: 30 }, [
                        'Graf je souvislý. ',
                        'Cesta P = ',
                        bs.em({}, '(y, d, c, x)'),
                    ], undefined, colors.blueHighlight, 0),

                    a.editVertex('b', undefined, 'x', colors.blueHighlight, 7, colors.blueHighlightLight, undefined, 0),
                    a.editVertex('g', undefined, 'y', colors.blueHighlight, 7, colors.blueHighlightLight, undefined, 0),
                    a.editVertex('d', undefined, undefined, undefined, undefined, colors.blueHighlightLight, undefined, 2000),
                    a.editVertex('c', undefined, undefined, undefined, undefined, colors.blueHighlightLight, undefined, 3000),

                    a.highlightEdge('d-g', a.HighlightType.Full, undefined,
                        colors.blueHighlight, undefined, undefined, 1000, 'd-g-blue'),
                    a.highlightEdge('c-d', a.HighlightType.Full, undefined,
                        colors.blueHighlight, undefined, undefined, 2000, 'c-d-blue'),
                    a.highlightEdge('b-c', a.HighlightType.Full, undefined,
                        colors.blueHighlight, undefined, undefined, 3000, 'b-c-blue'),
                ],
                sentence: {
                    text: [
                        bs.strong({}, 'Strom'), ' je souvislý graf, který neobsahuje kružnici.',
                        bs.e({ tag: 'br' }),
                        bs.strong({}, 'Souvislý graf'), ' je graf, ve kterém existuje mezi každými jeho dvěma vrcholy cesta. ',
                    ]
                },
                time: 5300
            },
            { // 6
                actions: [
                    a.removeHint('dukaz-3'),
                    a.addHint('dukaz-4', { x: 100, y: 20 }, [
                        'Cesta P = ',
                        bs.em({}, '(y, d, c, x)'),
                        bs.e({ tag: 'br' }),
                        'Hrana ',
                        bs.em({}, '{x, y}'),
                    ], undefined, colors.blueHighlight, 0),

                    a.addEdge('b-g', 'b', 'g', undefined, 7, colors.redHighlight)
                ],
                sentence: {
                    text: [
                        bs.strong({}, 'Souvislý graf'), ' je graf, ve kterém existuje mezi každými jeho dvěma vrcholy cesta. ',
                        bs.e({ tag: 'br' }),
                        bs.strong({}, 'Cesta'), ' je sled s navzájem různými vrcholy, tj. pro ',
                        bs.em({}, 'i'), ' \u2260 ', bs.em({}, 'j'),
                        ' platí ',
                        bs.em({}, ['v', bs.sub({}, 'i')]), ' \u2260 ', bs.em({}, ['v', bs.sub({}, 'j')]),
                    ]
                },
                time: 400
            },
            { // 7
                actions: [
                    a.removeHint('dukaz-4'),
                    a.addHint('dukaz-42', { x: 200, y: 20 }, [
                        'Kružnice ',
                        bs.em({}, '(x, y, d, c, x)'),
                    ], undefined, colors.blueHighlight, 0),
                ],
                sentence: {
                    text: [
                        bs.strong({}, 'Kružnice (cyklus)'), ' v grafu ',
                        bs.em({}, 'G'),
                        ' je posloupnost',
                        bs.em({}, [
                            '(v',
                            bs.sub({}, '0'), ', e',
                            bs.sub({}, '1'), ', v',
                            bs.sub({}, '1'), ', ..., e',
                            bs.sub({}, 'k'), ', v',
                            bs.sub({}, '0'), ')'
                        ]),
                        ' kde ',
                        bs.em({}, ['e', bs.sub({}, 'i')]), ' = ', bs.em({}, ['{v', bs.sub({}, 'i-1'), ', v', bs.sub({}, 'i'), '}, i']),
                        ' = ', bs.em({}, ['1,..., k-1; ']),
                        bs.em({}, ['e', bs.sub({}, 'k')]), ' = ', bs.em({}, ['{v', bs.sub({}, 'k-1'), ', v', bs.sub({}, '0'), '}'
                        ]),
                    ]
                },
                time: 600
            },
            { // 8
                actions: [
                    a.removeHint('dukaz-42'),

                    a.editVertex('b', undefined, 'b', colors.defaultBlack, 3, colors.defaultVertex, undefined, 0),
                    a.editVertex('g', undefined, 'g', colors.defaultBlack, 3, colors.defaultVertex, undefined, 0),
                    a.editVertex('c', undefined, undefined, colors.defaultBlack, 3, colors.defaultVertex, undefined, 0),
                    a.editVertex('d', undefined, undefined, colors.defaultBlack, 3, colors.defaultVertex, undefined, 0),

                    a.removeEdge('b-g'),
                    a.unHighlightEdge('d-g-blue', a.HighlightType.Full),
                    a.unHighlightEdge('c-d-blue', a.HighlightType.Full),
                    a.unHighlightEdge('b-c-blue', a.HighlightType.Full),
                ],
                sentence: {
                    text: [
                        bs.strong({}, 'Strom'), ' je souvislý graf, který neobsahuje kružnici. Značíme písmenem ',
                        bs.em({}, 'T'), ' (ze slova tree).',
                        bs.e({ tag: 'br' }),
                        bs.strong({}, 'Kružnice (cyklus)'), ' v grafu ',
                        bs.em({}, 'G'),
                        ' je posloupnost',
                        bs.em({}, [
                            '(v',
                            bs.sub({}, '0'), ', e',
                            bs.sub({}, '1'), ', v',
                            bs.sub({}, '1'), ', ..., e',
                            bs.sub({}, 'k'), ', v',
                            bs.sub({}, '0'), ')'
                        ]),
                        ' kde ',
                        bs.em({}, ['e', bs.sub({}, 'i')]), ' = ', bs.em({}, ['{v', bs.sub({}, 'i-1'), ', v', bs.sub({}, 'i'), '}, i']),
                        ' = ', bs.em({}, ['1,..., k-1; ']),
                        bs.em({}, ['e', bs.sub({}, 'k')]), ' = ', bs.em({}, ['{v', bs.sub({}, 'k-1'), ', v', bs.sub({}, '0'), '}'
                        ])
                    ]
                },
                time: 500
            },
            { // 9
                actions: [
                    a.addHint('dukaz-6', { x: 200, y: 10 }, [
                        'Předpokládáme, že ',
                        bs.em({}, 'T'),
                        ' není strom.',
                    ], undefined, colors.pinkHighlight, 0),

                    a.addEdge('c-e', 'c', 'e'),
                    a.removeEdge('b-c')
                ],
                sentence: {
                    text: [
                        bs.strong({}, 'Důkaz sporem: '),
                        bs.e({ tag: 'br' }),
                        'Vytvoříme negaci věty, odvozujeme logické důsledky až dojdeme k výroku ',
                        bs.em({}, ['S']), ', který je nepravdivý. Negace věty tedy neplatí, platí původní věta. ',
                        bs.e({ tag: 'br' }),
                        'Věta: ',
                        bs.em({}, 'A'), ' \u21D2 ', bs.em({}, 'B'),
                        ', negace: ',
                        bs.em({}, 'A'), ' \u2227 ', bs.em({}, 'B\u2032')
                    ]
                },
                time: 600
            },
            { // 10
                actions: [
                    a.removeHint('dukaz-6'),
                    a.addHint('dukaz-7', { x: 200, y: 20 }, [
                        'Graf není strom, protože obsahuje kružnici.',
                    ],
                        undefined, colors.purpleHighlight, 0),
                ],
                sentence: {
                    text: [
                        bs.strong({}, 'Strom'), ' je souvislý graf, který neobsahuje kružnici. ',
                        bs.e({ tag: 'br' }),
                        bs.strong({}, 'Kružnice (cyklus)'), ' v grafu ',
                        bs.em({}, 'G'),
                        ' je posloupnost',
                        bs.em({}, [
                            '(v',
                            bs.sub({}, '0'), ', e',
                            bs.sub({}, '1'), ', v',
                            bs.sub({}, '1'), ', ..., e',
                            bs.sub({}, 'k'), ', v',
                            bs.sub({}, '0'), ')'
                        ]),
                        ' kde ',
                        bs.em({}, ['e', bs.sub({}, 'i')]), ' = ', bs.em({}, ['{v', bs.sub({}, 'i-1'), ', v', bs.sub({}, 'i'), '}, i']),
                        ' = ', bs.em({}, ['1,..., k-1; ']),
                        bs.em({}, ['e', bs.sub({}, 'k')]), ' = ', bs.em({}, ['{v', bs.sub({}, 'k-1'), ', v', bs.sub({}, '0'), '}'
                        ]),
                    ]
                },
                time: 300
            },
            { // 11
                actions: [
                    a.removeHint('dukaz-7'),
                    a.addHint('dukaz-8', { x: 200, y: 380 }, [
                        'Graf není strom, protože je nesouvislý. ',
                    ], undefined, colors.redHighlight, 0),

                    a.removeEdge('c-e'),
                    a.editVertex('a', undefined, undefined, undefined, undefined, colors.greenHighlightLight),
                    a.editVertex('b', undefined, undefined, undefined, undefined, colors.greenHighlightLight),
                    a.editVertex('i', undefined, undefined, undefined, undefined, colors.greenHighlightLight),
                    a.editVertex('c', undefined, undefined, undefined, undefined, colors.orangeHighlightLight),
                    a.editVertex('f', undefined, undefined, undefined, undefined, colors.orangeHighlightLight),
                    a.editVertex('d', undefined, undefined, undefined, undefined, colors.orangeHighlightLight),
                    a.editVertex('g', undefined, undefined, undefined, undefined, colors.orangeHighlightLight),
                    a.editVertex('h', undefined, undefined, undefined, undefined, colors.orangeHighlightLight),
                    a.editVertex('e', undefined, undefined, undefined, undefined, colors.orangeHighlightLight)
                ],
                sentence: {
                    text: [
                        bs.strong({}, 'Strom'), ' je souvislý graf, který neobsahuje kružnici. ',
                        bs.e({ tag: 'br' }),
                        bs.strong({}, 'Komponenta grafu'),
                        ' je maximální souvislý podgraf grafu (není podgrafem jiného souvislého podgrafu). ',
                    ]
                },
                time: 500
            },
            { // 12
                actions: [
                    a.removeHint('dukaz-8'),
                    a.addHint('dukaz-9', { x: 200, y: 380 }, [
                        'Přidali jsme hranu ',
                        bs.em({}, '{x, y}'),
                    ], undefined, colors.redHighlight, 0),

                    a.editVertex('b', undefined, 'x'),
                    a.editVertex('c', undefined, 'y'),
                    a.addEdge('b-c', 'b', 'c'),
                    a.highlightEdge('b-c', a.HighlightType.Full, undefined,
                        colors.redHighlight, undefined, undefined, undefined, 'b-c-red'),
                ],
                sentence: {
                    text: [
                        bs.strong({}, 'Komponenta grafu'),
                        ' je maximální souvislý podgraf grafu (není podgrafem jiného souvislého podgrafu). ',
                    ]
                },
                time: 300
            },
            { // 13
                actions: [
                    a.removeHint('dukaz-9'),
                    a.addHint('dukaz-10', { x: 200, y: 370 }, [
                        'Hrana ',
                        bs.em({}, '{x, y}'), ' je most.',
                    ], undefined, colors.redHighlight, 0),
                ],
                sentence: {
                    text: [
                        bs.strong({}, 'Komponenta grafu'),
                        ' je maximální souvislý podgraf grafu (není podgrafem jiného souvislého podgrafu). ',
                        bs.e({ tag: 'br' }),
                        'Hrana ',
                        bs.em({}, 'e'), ' je ',
                        bs.strong({}, 'most'),
                        ' grafu ',
                        bs.em({}, 'G'), ', jestliže graf ',
                        bs.em({}, 'G '), '-', bs.em({}, ' e'), ' má více komponent než graf ',
                        bs.em({}, 'G'), '.',
                    ]
                },
                time: 400
            }
        ]
    }
];