import * as b from 'bobril';
import * as bs from 'bobrilstrap';
import * as a from '../viewer/actions';
import { negationsViewer } from '../viewer/negationsViewer';
import * as colors from '../common/colors';

const tableStyle = b.styleDef({
    width: 200,
    marginLeft: 'auto',
    marginRight: 'auto'
});

const tableKvantStyle = b.styleDef({
    width: 900,
    marginLeft: 'auto',
    marginRight: 'auto'
});

export const negace = b.createVirtualComponent({
    id: 'negace',
    render(ctx: b.IBobrilCtx, me: b.IBobrilNode) {
        me.children = [
            bs.h2({}, 'Vizualizace negací kvantifikovaných výroků'),
            bs.paragraph({}, ['']),
            negationsViewer({ examples, negations: true }),
            bs.elem({ tag: 'br' }),
            bs.paragraph({}, ['Zdroje obrázků: ']),
            bs.a({ href: 'https://pixabay.com' }, 'https://pixabay.com'), ' licence CC0 Public Domain',
            bs.elem({ tag: 'br' }),
            bs.a({ href: 'http://pngimg.com' }, 'http://pngimg.com'), ' licence ', 
            bs.a({ href: 'http://pngimg.com/license' }, 'http://pngimg.com/license'),
        ];
    }
});

const examples = () => [
    {
        name: 'negace-priklad-1',
        steps: [
            {
                actions: [
                    a.addHint('negace-1', { x: 280, y: 60 }, [
                        'Proveďte negaci:',
                        bs.e({ tag: 'br' }),
                        ' V batohu mám právě 3 čokolády.'],
                        undefined,
                        colors.blueHighlight, 0),
                ]
            },
            {
                actions: [
                    a.addAxis('axis'),
                    a.addEdge('edge-0', { x: 100, y: 225 }, { x: 100, y: 275 }),
                    a.addEdge('edge-2', { x: 300, y: 225 }, { x: 300, y: 275 }),
                    a.addEdge('edge-4', { x: 500, y: 225 }, { x: 500, y: 275 }),
                    a.addText('whiteboard-0', { x: 90, y: 310 }, [
                        '0'
                    ]),
                    a.addText('whiteboard-1', { x: 390, y: 310 }, [
                        '3'
                    ]),
                    a.addText('whiteboard-2', { x: 290, y: 310 }, [
                        '2'
                    ]),
                    a.addText('whiteboard-4', { x: 490, y: 310 }, [
                        '4'
                    ]),
                ]
            },
            {
                actions: [
                    a.editHint('negace-1', undefined, [
                        'Proveďte negaci:',
                        bs.e({ tag: 'br' }),
                        ' V batohu mám ', bs.strong({}, bs.underlined({}, 'právě')), ' 3 čokolády.',
                    ]),
                    a.addVertex('3', { x: 400, y: 250 }, '', colors.blueHighlight, 5, colors.blueHighlightLight, false),
                    a.addImage('chocolate-31', { x: 330, y: 320 }, 90, 90, "chocolate"),
                    a.addImage('chocolate-32', { x: 360, y: 320 }, 90, 90, "chocolate"),
                    a.addImage('chocolate-33', { x: 390, y: 320 }, 90, 90, "chocolate")
                ]
            },
            {
                actions: [
                    a.removeHint('negace-1'),
                    a.addHint('negace-2', { x: 239, y: 15 }, [
                        'Jak provést negaci: ',
                        bs.e({ tag: 'br' }),
                        'kdy není pravdou výrok, že mám právě 3 čokolády?'
                    ], undefined, colors.redHighlight, 0)
                ]
            },
            {
                actions: [
                    a.removeHint('negace-2'),
                    a.addHint('negace-8', { x: 239, y: 15 }, [
                        'Když mám méně než 3 čokolády - ',
                        bs.e({ tag: 'br' }),
                        'mohu mít 1 čokoládu, 0,5 čokolády, 2 čokolády...',
                    ], undefined, colors.redHighlight, 0),
                    a.addHalfCircle('half-2', { x: 679, y: 125 }, true, colors.redHighlightLight, colors.redHighlight, 5, 1),
                    a.editVertex('3', undefined, undefined, colors.defaultBlack, 3, colors.defaultWhite, false),
                    a.removeItem('chocolate-31', scene => scene.images),
                    a.removeItem('chocolate-32', scene => scene.images),
                    a.removeItem('chocolate-33', scene => scene.images),
                    a.addImage('chocolate-21', { x: 130, y: 270 }, 90, 90, "chocolate"),
                    a.addImage('chocolate-22', { x: 160, y: 270 }, 90, 90, "chocolate"),
                ]
            },
            {
                actions: [
                    a.removeHint('negace-8'),
                    a.addHint('negace-3', { x: 264, y: 28 }, [
                        'Ale také mohu mít více než 3 čokolády - ',
                        bs.e({ tag: 'br' }),
                        '3,5 čokolády, 20 čokolád, 4 čokolády...',
                    ], undefined, colors.redHighlight, 0),
                    a.addHalfCircle('half-1', { x: 754, y: 125 }, undefined, colors.redHighlightLight, colors.redHighlight, 5, 1),
                    a.addImage('chocolate-41', { x: 530, y: 270 }, 90, 90, "chocolate"),
                    a.addImage('chocolate-42', { x: 560, y: 270 }, 90, 90, "chocolate"),
                    a.addImage('chocolate-43', { x: 590, y: 270 }, 90, 90, "chocolate"),
                    a.addImage('chocolate-44', { x: 620, y: 270 }, 90, 90, "chocolate"),
                ]
            },
            {
                actions: [
                    a.removeHint('negace-3'),
                    a.addHint('negace-4', { x: 264, y: 28 }, [
                        'Negace výroku tedy zní:',
                        bs.e({ tag: 'br' }),
                        ' V batohu mám ', bs.strong({}, bs.underlined({}, 'méně nebo více než')), ' 3 čokolády.',
                    ], undefined, colors.redHighlight, 0),
                ]
            },
            {
                actions: [
                    a.removeHint('negace-4'),
                    a.addHint('negace-5', { x: 280, y: 60 }, [
                        'Výrok a negace mají nulový průnik',
                        bs.e({ tag: 'br' }),
                        '(nemají žádné společné body)',
                    ], undefined, colors.redHighlight, 0),
                    a.editVertex('3', undefined, undefined, colors.blueHighlight, 5, colors.blueHighlightLight, false),
                    a.addImage('chocolate-31', { x: 330, y: 320 }, 90, 90, "chocolate"),
                    a.addImage('chocolate-32', { x: 360, y: 320 }, 90, 90, "chocolate"),
                    a.addImage('chocolate-33', { x: 390, y: 320 }, 90, 90, "chocolate")
                ]
            },
            {
                actions: [
                    a.removeHint('negace-5'),
                    a.addHint('negace-6', { x: 280, y: 60 }, [
                        'Sjednocení výroku a jeho negace',
                        bs.e({ tag: 'br' }),
                        'pokryje celou osu (všechny body)',
                    ], undefined, colors.purpleHighlight, 0),
                    a.editHalfCircle('half-1', { x: 754, y: 125 }, undefined, colors.purpleHighlightLight, colors.purpleHighlight, 5, 1),
                    a.editHalfCircle('half-2', { x: 679, y: 125 }, true, colors.purpleHighlightLight, colors.purpleHighlight, 5, 1),
                    a.editVertex('3', undefined, undefined, colors.purpleHighlight, 5, colors.purpleHighlightLight, false),
                ]
            }
        ]
    },
    {
        name: 'negace-priklad-2',
        steps: [
            {
                actions: [
                    a.addHint('negace-2-1', { x: 270, y: 80 }, [
                        'Proveďte negaci:',
                        bs.e({ tag: 'br' }),
                        ' Alespoň čtyři studenti rozumí negacím.'],
                        undefined,
                        colors.blueHighlight, 0),
                ]
            },
            {
                actions: [
                    a.addAxis('axis'),
                    a.addEdge('edge-0', { x: 100, y: 225 }, { x: 100, y: 275 }, undefined, undefined, undefined, undefined, 70),
                    a.addEdge('edge-3', { x: 325, y: 225 }, { x: 325, y: 275 }, undefined, undefined, undefined, undefined, 70),
                    a.addEdge('edge-5', { x: 475, y: 225 }, { x: 475, y: 275 }, undefined, undefined, undefined, undefined, 70),
                    a.addEdge('edge-2', { x: 250, y: 225 }, { x: 250, y: 275 }, undefined, undefined, undefined, undefined, 70),
                    a.addEdge('edge-1', { x: 175, y: 225 }, { x: 175, y: 275 }, undefined, undefined, undefined, undefined, 70),
                    a.addEdge('edge-6', { x: 550, y: 225 }, { x: 550, y: 275 }, undefined, undefined, undefined, undefined, 70),
                    a.addEdge('edge-7', { x: 625, y: 225 }, { x: 625, y: 275 }, undefined, undefined, undefined, undefined, 70),
                    a.addText('whiteboard-0', { x: 90, y: 310 }, [
                        '0'
                    ]),
                    a.addText('whiteboard-1', { x: 390, y: 310 }, [
                        '4'
                    ]),
                    a.addText('whiteboard-2', { x: 315, y: 310 }, [
                        '3'
                    ]),
                    a.addText('whiteboard-4', { x: 465, y: 310 }, [
                        '5'
                    ]),
                    a.addText('whiteboard-2', { x: 240, y: 310 }, [
                        '2'
                    ]),
                    a.addText('whiteboard-4', { x: 165, y: 310 }, [
                        '1'
                    ]),
                    a.addText('whiteboard-2', { x: 540, y: 310 }, [
                        '6'
                    ]),
                    a.addText('whiteboard-4', { x: 615, y: 310 }, [
                        '7'
                    ]),
                ]
            },
            {
                actions: [
                    a.editHint('negace-2-1', undefined, [
                        'Proveďte negaci:',
                        bs.e({ tag: 'br' }),
                        bs.strong({}, bs.underlined({}, 'Alespoň čtyři')), ' studenti rozumí negacím.',
                    ]),
                ]
            },
            {
                actions: [
                    a.removeHint('negace-2-1'),
                    a.addHint('negace-2-2', { x: 270, y: 140 }, [
                        'Alespoň (přinejmenším) čtyři studenti negacím rozumí - ',
                        bs.e({ tag: 'br' }),
                        'jak to jde vyjádřit na ose?'
                    ], undefined, colors.blueHighlight, 0)
                ]
            },
            {
                actions: [
                    a.removeHint('negace-2-2'),
                    a.addHint('negace-2-8', { x: 340, y: 370 }, [
                        'Minimálně čtyři studenti rozumí negacím, ',
                        bs.e({ tag: 'br' }),
                        'tedy jim může rozumět i pět studentů, šest studentů...',
                        bs.e({ tag: 'br' }),
                        'Zkrátka více nebo rovno čtyřem na ose celých čísel.',
                    ], undefined, colors.blueHighlight, 0),
                    a.addVertex('4', { x: 400, y: 250 }, '', colors.blueHighlight, 5, colors.blueHighlightLight, false),
                    a.addVertex('5', { x: 475, y: 250 }, '', colors.blueHighlight, 5, colors.blueHighlightLight, false),
                    a.addVertex('6', { x: 550, y: 250 }, '', colors.blueHighlight, 5, colors.blueHighlightLight, false),
                    a.addVertex('7', { x: 625, y: 250 }, '', colors.blueHighlight, 5, colors.blueHighlightLight, false),
                    a.addImage('student-22', { x: 460, y: 50 }, 90, 90, "student"),
                    a.addImage('student-24', { x: 530, y: 50 }, 90, 90, "student"),
                    a.addImage('student-26', { x: 610, y: 50 }, 90, 90, "student"),
                    a.addImage('student-21', { x: 420, y: 100 }, 90, 90, "student"),
                    a.addImage('student-23', { x: 490, y: 100 }, 90, 90, "student"),
                    a.addImage('student-25', { x: 570, y: 100 }, 90, 90, "student"),
                ]
            },
            {
                actions: [
                    a.removeHint('negace-2-8'),
                    a.addHint('negace-2-3', { x: 108, y: 370 }, [
                        'Opakem více nebo rovno čtyřem je méně než čtyři.',
                        bs.e({ tag: 'br' }),
                        'Je možné, že negacím rozumí pouze jeden student,',
                        bs.e({ tag: 'br' }),
                        'dva studenti, maximálně tři studenti.',
                        bs.e({ tag: 'br' }),
                        'Jinak řečeno "nejvýše tři" studenti.',
                    ], undefined, colors.redHighlight, 0),
                    a.removeItem('student-21', scene => scene.images),
                    a.removeItem('student-22', scene => scene.images),
                    a.removeItem('student-23', scene => scene.images),
                    a.removeItem('student-24', scene => scene.images),
                    a.removeItem('student-25', scene => scene.images),
                    a.removeItem('student-26', scene => scene.images),
                    a.addImage('student-41', { x: 190, y: 100 }, 90, 90, "student"),
                    a.addImage('student-42', { x: 220, y: 100 }, 90, 90, "student"),
                    a.addImage('student-43', { x: 250, y: 100 }, 90, 90, "student"),
                    a.removeVertex('4'),
                    a.removeVertex('5'),
                    a.removeVertex('6'),
                    a.removeVertex('7'),
                ]
            },
            {
                actions: [
                    a.removeHint('negace-2-3'),
                    a.addHint('negace-2-4', { x: 170, y: 28 }, [
                        'Negace výroku tedy zní:',
                        bs.e({ tag: 'br' }),
                        bs.strong({}, bs.underlined({}, 'Nejvýše tři')), ' studenti rozumí negacím.',
                    ], undefined, colors.redHighlight, 0),
                    a.addVertex('0', { x: 100, y: 250 }, '', colors.redHighlight, 5, colors.redHighlightLight, false),
                    a.addVertex('1', { x: 175, y: 250 }, '', colors.redHighlight, 5, colors.redHighlightLight, false),
                    a.addVertex('2', { x: 250, y: 250 }, '', colors.redHighlight, 5, colors.redHighlightLight, false),
                    a.addVertex('3', { x: 325, y: 250 }, '', colors.redHighlight, 5, colors.redHighlightLight, false)
                ]
            },
            {
                actions: [
                    a.removeHint('negace-2-4'),
                    a.addHint('negace-2-5', { x: 250, y: 390 }, [
                        'Výrok a negace mají nulový průnik',
                        bs.e({ tag: 'br' }),
                        '(nemají žádné společné body)',
                    ], undefined, colors.redHighlight, 0),
                    a.addVertex('4', { x: 400, y: 250 }, '', colors.blueHighlight, 5, colors.blueHighlightLight, false),
                    a.addVertex('5', { x: 475, y: 250 }, '', colors.blueHighlight, 5, colors.blueHighlightLight, false),
                    a.addVertex('6', { x: 550, y: 250 }, '', colors.blueHighlight, 5, colors.blueHighlightLight, false),
                    a.addVertex('7', { x: 625, y: 250 }, '', colors.blueHighlight, 5, colors.blueHighlightLight, false),
                    a.addImage('student-22', { x: 460, y: 50 }, 90, 90, "student"),
                    a.addImage('student-24', { x: 530, y: 50 }, 90, 90, "student"),
                    a.addImage('student-26', { x: 610, y: 50 }, 90, 90, "student"),
                    a.addImage('student-21', { x: 420, y: 100 }, 90, 90, "student"),
                    a.addImage('student-23', { x: 490, y: 100 }, 90, 90, "student"),
                    a.addImage('student-25', { x: 570, y: 100 }, 90, 90, "student"),
                ]
            },
            {
                actions: [
                    a.removeHint('negace-2-5'),
                    a.addHint('negace-2-6', { x: 250, y: 390 }, [
                        'Sjednocení výroku a jeho negace',
                        bs.e({ tag: 'br' }),
                        'pokryje celou osu (všechny body).',
                    ], undefined, colors.purpleHighlight, 0),
                    a.editVertex('0', undefined, undefined, colors.purpleHighlight, 5, colors.purpleHighlightLight, false),
                    a.editVertex('1', undefined, undefined, colors.purpleHighlight, 5, colors.purpleHighlightLight, false),
                    a.editVertex('2', undefined, undefined, colors.purpleHighlight, 5, colors.purpleHighlightLight, false),
                    a.editVertex('3', undefined, undefined, colors.purpleHighlight, 5, colors.purpleHighlightLight, false),
                    a.editVertex('4', undefined, undefined, colors.purpleHighlight, 5, colors.purpleHighlightLight, false),
                    a.editVertex('5', undefined, undefined, colors.purpleHighlight, 5, colors.purpleHighlightLight, false),
                    a.editVertex('6', undefined, undefined, colors.purpleHighlight, 5, colors.purpleHighlightLight, false),
                    a.editVertex('7', undefined, undefined, colors.purpleHighlight, 5, colors.purpleHighlightLight, false),
                ]
            },
        ]
    },
    {
        name: 'negace-priklad-3',
        steps: [
            {
                actions: [
                    a.addHint('negace-3-1', { x: 270, y: 80 }, [
                        'Proveďte negaci:',
                        bs.e({ tag: 'br' }),
                        ' Snědl jsem nejvýše tři hamburgery.'],
                        undefined,
                        colors.blueHighlight, 0),
                ]
            },
            {
                actions: [
                    a.addAxis('axis'),
                    a.addEdge('edge-0', { x: 100, y: 225 }, { x: 100, y: 275 }, undefined, undefined, undefined, undefined, 70),
                    a.addEdge('edge-3', { x: 325, y: 225 }, { x: 325, y: 275 }, undefined, undefined, undefined, undefined, 70),
                    a.addEdge('edge-5', { x: 475, y: 225 }, { x: 475, y: 275 }, undefined, undefined, undefined, undefined, 70),
                    a.addEdge('edge-2', { x: 250, y: 225 }, { x: 250, y: 275 }, undefined, undefined, undefined, undefined, 70),
                    a.addEdge('edge-1', { x: 175, y: 225 }, { x: 175, y: 275 }, undefined, undefined, undefined, undefined, 70),
                    a.addEdge('edge-6', { x: 550, y: 225 }, { x: 550, y: 275 }, undefined, undefined, undefined, undefined, 70),
                    a.addEdge('edge-7', { x: 625, y: 225 }, { x: 625, y: 275 }, undefined, undefined, undefined, undefined, 70),
                    a.addText('whiteboard-0', { x: 90, y: 310 }, [
                        '0'
                    ]),
                    a.addText('whiteboard-1', { x: 390, y: 310 }, [
                        '4'
                    ]),
                    a.addText('whiteboard-2', { x: 315, y: 310 }, [
                        '3'
                    ]),
                    a.addText('whiteboard-4', { x: 465, y: 310 }, [
                        '5'
                    ]),
                    a.addText('whiteboard-2', { x: 240, y: 310 }, [
                        '2'
                    ]),
                    a.addText('whiteboard-4', { x: 165, y: 310 }, [
                        '1'
                    ]),
                    a.addText('whiteboard-2', { x: 540, y: 310 }, [
                        '6'
                    ]),
                    a.addText('whiteboard-4', { x: 615, y: 310 }, [
                        '7'
                    ]),
                ]
            },
            {
                actions: [
                    a.editHint('negace-3-1', undefined, [
                        'Proveďte negaci:',
                        bs.e({ tag: 'br' }),
                        'Snědl jsem ', bs.strong({}, bs.underlined({}, 'nejvýše')), ' tři hamburgery.',
                    ]),
                ]
            },
            {
                actions: [
                    a.removeHint('negace-3-1'),
                    a.addHint('negace-3-2', { x: 200, y: 140 }, [
                        'Snědl jsem nejvýše (maximálně) tři hamburgery - ',
                        bs.e({ tag: 'br' }),
                        'jak to jde vyjádřit na ose?'
                    ], undefined, colors.blueHighlight, 0)
                ]
            },
            {
                actions: [
                    a.removeHint('negace-3-2'),
                    a.addHint('negace-3-8', { x: 40, y: 370 }, [
                        'Snědl jsem maximálně tři, tedy jsem nemusel sníst žádný, ',
                        bs.e({ tag: 'br' }),
                        'mohl jsem sníst i jeden nebo dva hamburgery. ',
                        bs.e({ tag: 'br' }),
                        'To odpovídá číslům 0 až 3 na ose celých čísel.',
                    ], undefined, colors.blueHighlight, 0),
                    a.addVertex('0', { x: 100, y: 250 }, '', colors.blueHighlight, 5, colors.blueHighlightLight, false),
                    a.addVertex('1', { x: 175, y: 250 }, '', colors.blueHighlight, 5, colors.blueHighlightLight, false),
                    a.addVertex('2', { x: 250, y: 250 }, '', colors.blueHighlight, 5, colors.blueHighlightLight, false),
                    a.addVertex('3', { x: 325, y: 250 }, '', colors.blueHighlight, 5, colors.blueHighlightLight, false),
                    a.addImage('hamburger-22', { x: 130, y: 80 }, 90, 90, "hamburger"),
                    a.addImage('hamburger-24', { x: 200, y: 80 }, 90, 90, "hamburger"),
                    a.addImage('hamburger-26', { x: 270, y: 80 }, 90, 90, "hamburger"),
                ]
            },
            {
                actions: [
                    a.removeHint('negace-3-8'),
                    a.addHint('negace-3-3', { x: 390, y: 370 }, [
                        'Opakem méně nebo rovno třem je více než tři.',
                        bs.e({ tag: 'br' }),
                        'Je možné, že jsem snědl čtyři hamburgery,',
                        bs.e({ tag: 'br' }),
                        'pět, šest nebo tisíc hamburgerů.',
                        bs.e({ tag: 'br' }),
                        'Jinak řečeno "alespoň čtyři" hamburgery.',
                    ], undefined, colors.redHighlight, 0),
                    a.removeItem('hamburger-22', scene => scene.images),
                    a.removeItem('hamburger-24', scene => scene.images),
                    a.removeItem('hamburger-26', scene => scene.images),
                    a.addImage('hamburger-44', { x: 520, y: 70 }, 90, 90, "hamburger"),
                    a.addImage('hamburger-42', { x: 440, y: 70 }, 90, 90, "hamburger"),
                    a.addImage('hamburger-46', { x: 600, y: 70 }, 90, 90, "hamburger"),
                    a.addImage('hamburger-41', { x: 400, y: 100 }, 90, 90, "hamburger"),
                    a.addImage('hamburger-43', { x: 480, y: 100 }, 90, 90, "hamburger"),
                    a.addImage('hamburger-45', { x: 560, y: 100 }, 90, 90, "hamburger"),
                    a.removeVertex('0'),
                    a.removeVertex('1'),
                    a.removeVertex('2'),
                    a.removeVertex('3'),
                ]
            },
            {
                actions: [
                    a.removeHint('negace-3-3'),
                    a.addHint('negace-3-4', { x: 370, y: 28 }, [
                        'Negace výroku tedy zní:',
                        bs.e({ tag: 'br' }),
                        'Snědl jsem ', bs.strong({}, bs.underlined({}, 'alespoň')), ' čtyři hamburgery.',
                    ], undefined, colors.redHighlight, 0),
                    a.addVertex('4', { x: 400, y: 250 }, '', colors.redHighlight, 5, colors.redHighlightLight, false),
                    a.addVertex('5', { x: 475, y: 250 }, '', colors.redHighlight, 5, colors.redHighlightLight, false),
                    a.addVertex('6', { x: 550, y: 250 }, '', colors.redHighlight, 5, colors.redHighlightLight, false),
                    a.addVertex('7', { x: 625, y: 250 }, '', colors.redHighlight, 5, colors.redHighlightLight, false),
                ]
            },
            {
                actions: [
                    a.removeHint('negace-3-4'),
                    a.addHint('negace-3-5', { x: 250, y: 390 }, [
                        'Výrok a negace mají nulový průnik',
                        bs.e({ tag: 'br' }),
                        '(nemají žádné společné body)',
                    ], undefined, colors.redHighlight, 0),
                    a.addVertex('0', { x: 100, y: 250 }, '', colors.blueHighlight, 5, colors.blueHighlightLight, false),
                    a.addVertex('1', { x: 175, y: 250 }, '', colors.blueHighlight, 5, colors.blueHighlightLight, false),
                    a.addVertex('2', { x: 250, y: 250 }, '', colors.blueHighlight, 5, colors.blueHighlightLight, false),
                    a.addVertex('3', { x: 325, y: 250 }, '', colors.blueHighlight, 5, colors.blueHighlightLight, false),
                    a.addImage('hamburger-22', { x: 130, y: 80 }, 90, 90, "hamburger"),
                    a.addImage('hamburger-24', { x: 200, y: 80 }, 90, 90, "hamburger"),
                    a.addImage('hamburger-26', { x: 270, y: 80 }, 90, 90, "hamburger"),
                ]
            },
            {
                actions: [
                    a.removeHint('negace-3-5'),
                    a.addHint('negace-3-6', { x: 250, y: 390 }, [
                        'Sjednocení výroku a jeho negace',
                        bs.e({ tag: 'br' }),
                        'pokryje celou osu (všechny body).',
                    ], undefined, colors.purpleHighlight, 0),
                    a.editVertex('0', undefined, undefined, colors.purpleHighlight, 5, colors.purpleHighlightLight, false),
                    a.editVertex('1', undefined, undefined, colors.purpleHighlight, 5, colors.purpleHighlightLight, false),
                    a.editVertex('2', undefined, undefined, colors.purpleHighlight, 5, colors.purpleHighlightLight, false),
                    a.editVertex('3', undefined, undefined, colors.purpleHighlight, 5, colors.purpleHighlightLight, false),
                    a.editVertex('4', undefined, undefined, colors.purpleHighlight, 5, colors.purpleHighlightLight, false),
                    a.editVertex('5', undefined, undefined, colors.purpleHighlight, 5, colors.purpleHighlightLight, false),
                    a.editVertex('6', undefined, undefined, colors.purpleHighlight, 5, colors.purpleHighlightLight, false),
                    a.editVertex('7', undefined, undefined, colors.purpleHighlight, 5, colors.purpleHighlightLight, false),
                ]
            },
        ]
    },
    {
        name: 'negace-priklad-4',
        steps: [
            {
                actions: [
                    a.addHint('negace-4-1', { x: 270, y: 80 }, [
                        'Proveďte negaci:',
                        bs.e({ tag: 'br' }),
                        'Každé pivo má velkou bílou pěnu.  '],
                        undefined,
                        colors.blueHighlight, 0),
                ]
            },
            {
                actions: [
                    a.editHint('negace-4-1', undefined, [
                        'Proveďte negaci:',
                        bs.e({ tag: 'br' }),
                        bs.strong({}, bs.underlined({}, 'Každé')), ' pivo má velkou bílou pěnu. ',
                    ]),
                ]
            },
            {
                actions: [
                    a.removeHint('negace-4-1'),
                    a.addHint('negace-4-2', { x: 200, y: 140 }, [
                        'Tvrdíme, že každé pivo má velkou bílou pěnu - ',
                        bs.e({ tag: 'br' }),
                        'tedy že všechna piva mají velkou bílou pěnu.'
                    ], undefined, colors.blueHighlight, 0),
                    a.addImage('beer-22', { x: 100, y: 250 }, 90, 90, 'beer'),
                    a.addImage('beer-24', { x: 250, y: 250 }, 90, 90, 'beer'),
                    a.addImage('beer-26', { x: 400, y: 250 }, 90, 90, 'beer'),
                    a.addImage('beer-28', { x: 550, y: 250 }, 90, 90, 'beer'),
                ]
            },
            {
                actions: [
                    a.removeHint('negace-4-2'),
                    a.addHint('negace-4-3', { x: 250, y: 250 }, [
                        'Jako první nás může napadnout ',
                        bs.e({ tag: 'br' }),
                        'nesprávná negace: ',
                        bs.e({ tag: 'br' }),
                        'Každé pivo nemá velkou bílou pěnu. ',
                    ], undefined, colors.redHighlight, 0),
                    a.removeItem('beer-22', scene => scene.images),
                    a.removeItem('beer-24', scene => scene.images),
                    a.removeItem('beer-26', scene => scene.images),
                    a.removeItem('beer-28', scene => scene.images),
                ]
            },
            {
                actions: [
                    a.removeHint('negace-4-3'),
                    a.addHint('negace-4-9', { x: 250, y: 100 }, [
                        'To by znamenalo, že ',
                        bs.e({ tag: 'br' }),
                        'při platnosti negace ',
                        bs.e({ tag: 'br' }),
                        'všechna piva nemají ',
                        bs.e({ tag: 'br' }),
                        'velkou bílou pěnu. ',
                    ], undefined, colors.redHighlight, 0),
                ]
            },
            {
                actions: [
                    a.addImage('beer-32', { x: 100, y: 250 }, 90, 90, 'beerNo'),
                    a.addImage('beer-34', { x: 250, y: 250 }, 90, 90, 'beerNo'),
                    a.addImage('beer-36', { x: 400, y: 250 }, 90, 90, 'beerNo'),
                    a.addImage('beer-38', { x: 550, y: 250 }, 90, 90, 'beerNo'),
                ]
            },
            {
                actions: [
                    a.removeHint('negace-4-9'),
                    a.addHint('negace-4-10', { x: 200, y: 200 }, [
                        'Přitom ale může nastat situace, ',
                        bs.e({ tag: 'br' }),
                        'kdy pouze jedno pivo nemá velkou bílou pěnu.  ',
                        bs.e({ tag: 'br' }),
                        'Tímpádem není pravda, že ',
                        bs.e({ tag: 'br' }),
                        'všechna piva mají velkou bílou pěnu.',
                    ], undefined, colors.redHighlight, 0),
                    a.removeItem('beer-32', scene => scene.images),
                    a.removeItem('beer-34', scene => scene.images),
                    a.removeItem('beer-36', scene => scene.images),
                    a.removeItem('beer-38', scene => scene.images),
                ]
            },
            {
                actions: [
                    a.removeHint('negace-4-10'),
                    a.addHint('negace-4-3', { x: 390, y: 370 }, [
                        'Již jeden prvek co výrok nesplňuje ',
                        bs.e({ tag: 'br' }),
                        'stačí k tomu, aby byl výrok nepravdivý.',
                    ], undefined, colors.redHighlight, 0),
                    a.addImage('beer-22', { x: 100, y: 250 }, 90, 90, 'beer'),
                    a.addImage('beer-24', { x: 250, y: 250 }, 90, 90, 'beer'),
                    a.addImage('beer-26', { x: 400, y: 250 }, 90, 90, 'beer'),
                    a.addImage('beer-28', { x: 550, y: 250 }, 90, 90, 'beerNo'),
                ]
            },
            {
                actions: [
                    a.removeHint('negace-4-3'),
                    a.addHint('negace-4-4', { x: 230, y: 100 }, [
                        'Negace výroku tedy zní:',
                        bs.e({ tag: 'br' }),
                        'Existuje ', bs.strong({}, bs.underlined({}, 'alespoň jedno')), ' pivo, které nemá velkou bílou pěnu.',
                    ], undefined, colors.redHighlight, 0),
                ]
            },
        ]
    },
];